package flink.zanxiangnet.ad.monitoring.pojo.entity;

import com.google.gson.annotations.SerializedName;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeColumn;
import flink.zanxiangnet.ad.monitoring.maxcompute.bean.annotation.MaxComputeTable;
import flink.zanxiangnet.ad.monitoring.util.NumberUtil;
import flink.zanxiangnet.ad.monitoring.util.PlanUtil;
import lombok.Data;
import org.springframework.beans.BeanUtils;

import java.math.BigDecimal;
import java.util.*;

/**
 * 广告维度的小时统计数据
 */
@Data
@MaxComputeTable("plan_stat_of_minute_dwd")
public class PlanStatOfMinuteDWD {

    /**
     * 统计的日期（用于 MaxCompute分区）
     */
    @MaxComputeColumn(isPartitioned = true)
    @SerializedName("stat_day")
    private String statDay;

    /**
     * 统计的小时
     */
    @SerializedName("hour")
    private Integer hour;

    /**
     * 统计发起时间
     */
    @SerializedName("stat_time")
    private Long statTime;

    /**
     * 腾讯广告应用的账号 id
     */
    @SerializedName("account_id")
    private Long accountId;

    /**
     * 计划 id
     */
    @SerializedName("campaign_id")
    private Long campaignId;

    /**
     * 服务商账号 id
     */
    @SerializedName("agency_account_id")
    private Long agencyAccountId;

    /**
     * 微信账号id
     */
    @SerializedName("wechat_account_id")
    private String wechatAccountId;

    /**
     * 微信服务商id
     */
    @SerializedName("wechat_agency_id")
    private String wechatAgencyId;

    /**
     * 广告组与广告的映射关系
     */
    @MaxComputeColumn(ignore = true)
    @SerializedName("ad_group_map")
    private Map<Long, Set<Long>> adGroupMap;

    /**
     * 广告组与广告的映射关系
     */
    @SerializedName("ad_group_map_str")
    private String adGroupMapStr;

    /**
     * 广告 id列表
     */
    @MaxComputeColumn(ignore = true)
    @SerializedName("ad_ids")
    private Set<Long> adIds;

    /**
     * 广告 id列表
     */
    @SerializedName("ad_ids_str")
    private String adIdsStr;

    @SerializedName("create_time")
    private Date createTime;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_total")
    private BigDecimal costDeviationRateTotal;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_day")
    private BigDecimal costDeviationRateDay;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_hour")
    private BigDecimal costDeviationRateHour;

    /**
     * 当日成本偏差。反映广告今日的实际成本与目标成本直接的差异，注：该项成本相关数据按小时更新，与实时更新的「转化目标成本」数据存在出入属于正常情况。
     */
    @SerializedName("cost_deviation_rate_minute")
    private BigDecimal costDeviationRateMinute;

    /**
     * 消耗
     */
    @SerializedName("cost_total")
    private Long costTotal;

    /**
     * 消耗
     */
    @SerializedName("cost_day")
    private Long costDay;

    /**
     * 消耗
     */
    @SerializedName("cost_hour")
    private Long costHour;

    /**
     * 消耗
     */
    @SerializedName("cost_minute")
    private Long costMinute;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_total")
    private Long compensationAmountTotal;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_day")
    private Long compensationAmountDay;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_hour")
    private Long compensationAmountHour;

    /**
     * 赔付金额。智能优化成本保障政策下，广告超成本时的赔付金额。
     */
    @SerializedName("compensation_amount_minute")
    private Long compensationAmountMinute;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_total")
    private Long viewCountTotal;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_day")
    private Long viewCountDay;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_hour")
    private Long viewCountHour;

    /**
     * 曝光次数。用户观看广告的次数。
     */
    @SerializedName("view_count_minute")
    private Long viewCountMinute;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_all")
    private Long thousandDisplayPriceAll;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_day")
    private Long thousandDisplayPriceDay;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_hour")
    private Long thousandDisplayPriceHour;

    /**
     * 千次曝光成本。平均每千次曝光的花费。
     */
    @SerializedName("thousand_display_price_minute")
    private Long thousandDisplayPriceMinute;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_all")
    private BigDecimal avgViewPerUserAll;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_day")
    private BigDecimal avgViewPerUserDay;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_hour")
    private BigDecimal avgViewPerUserHour;

    /**
     * 人均曝光次数。每个用户观看广告的平均次数。
     */
    @SerializedName("avg_view_per_user_minute")
    private BigDecimal avgViewPerUserMinute;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_total")
    private Long validClickCountTotal;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_day")
    private Long validClickCountDay;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_hour")
    private Long validClickCountHour;

    /**
     * 点击次数。用户在广告外层进行点击操作的次数。包括点击图片/视频，及朋友圈广告“文字链、头像、昵称、门店、选择按钮”等所有广告外层区域的点击。
     */
    @SerializedName("valid_click_count_minute")
    private Long validClickCountMinute;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_all")
    private BigDecimal ctrAll;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_day")
    private BigDecimal ctrDay;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_hour")
    private BigDecimal ctrHour;

    /**
     * 点击率。看到广告后执行点击操作的百分比。计算逻辑：广告点击次数/广告曝光次数。
     */
    @SerializedName("ctr_minute")
    private BigDecimal ctrMinute;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_all")
    private Long cpcAll;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_day")
    private Long cpcDay;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_hour")
    private Long cpcHour;

    /**
     * 点击均价。一次广告点击的平均花费。计算逻辑：广告花费/广告点击次数。
     */
    @SerializedName("cpc_minute")
    private Long cpcMinute;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_total")
    private Long valuableClickCountTotal;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_day")
    private Long valuableClickCountDay;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_hour")
    private Long valuableClickCountHour;

    /**
     * 可转化点击次数。朋友圈：可转化点击是指可能产生转化的外层点击次数。对于“公众号推广”的广告，包括外层的公众号头像、公众号昵称、详情页查看、原生推广页查看； 对于其他类型的广告，包括外层的详情页查看和原生推广页查看。公众号：可转化点击是指可能产生转化的点击次数。
     */
    @SerializedName("valuable_click_count_minute")
    private Long valuableClickCountMinute;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_all")
    private BigDecimal valuableClickRateAll;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_day")
    private BigDecimal valuableClickRateDay;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_hour")
    private BigDecimal valuableClickRateHour;

    /**
     * 可转化点击率。用户看到广告后执行可转化点击操作的百分比。计算逻辑：广告可转化点击次数/广告曝光次数。
     */
    @SerializedName("valuable_click_rate_minute")
    private BigDecimal valuableClickRateMinute;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_all")
    private Long valuableClickCostAll;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_day")
    private Long valuableClickCostDay;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_hour")
    private Long valuableClickCostHour;

    /**
     * 可转化点击成本。一次可转化点击的平均花费。计算逻辑：广告花费/可转化点击次数。
     */
    @SerializedName("valuable_click_cost_minute")
    private Long valuableClickCostMinute;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_total")
    private Long conversionsCountTotal;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_day")
    private Long conversionsCountDay;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_hour")
    private Long conversionsCountHour;

    /**
     * 转化目标量。「转化目标」的具体数量，代表该广告的转化效果量级。
     */
    @SerializedName("conversions_count_minute")
    private Long conversionsCountMinute;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_all")
    private Long conversionsCostAll;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_day")
    private Long conversionsCostDay;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_hour")
    private Long conversionsCostHour;

    /**
     * 转化目标成本。广告产生一次转化目标的平均费用。计算逻辑：广告花费/转化目标量。
     */
    @SerializedName("conversions_cost_minute")
    private Long conversionsCostMinute;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_all")
    private BigDecimal conversionsRateAll;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_day")
    private BigDecimal conversionsRateDay;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_hour")
    private BigDecimal conversionsRateHour;

    /**
     * 目标转化率。朋友圈：转化目标量/可转化点击次数。公众号：转化目标量/点击次数。
     */
    @SerializedName("conversions_rate_minute")
    private BigDecimal conversionsRateMinute;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_total")
    private Long deepConversionsCountTotal;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_day")
    private Long deepConversionsCountDay;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_hour")
    private Long deepConversionsCountHour;

    /**
     * 深度转化目标量-灰度中。根据您选择的深度智能优化目标，该广告对应的具体数量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_count_minute")
    private Long deepConversionsCountMinute;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_all")
    private Long deepConversionsCostAll;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_day")
    private Long deepConversionsCostDay;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_hour")
    private Long deepConversionsCostHour;

    /**
     * 深度转化目标成本-灰度中。根据您选择的深度智能优化目标，该广告产生一次转化的平均费用。计算逻辑：广告花费/深度转化目标量。部分需接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_cost_minute")
    private Long deepConversionsCostMinute;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_all")
    private BigDecimal deepConversionsRateAll;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_day")
    private BigDecimal deepConversionsRateDay;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_hour")
    private BigDecimal deepConversionsRateHour;

    /**
     * 深度目标转化率-灰度中。朋友圈：深度转化目标量/可转化点击次数。公众号：深度转化目标量/点击次数。指标随深度转化功能灰度中。接入转化跟踪后可统计。
     */
    @SerializedName("deep_conversions_rate_minute")
    private BigDecimal deepConversionsRateMinute;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_total")
    private Long orderCountTotal;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_day")
    private Long orderCountDay;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_hour")
    private Long orderCountHour;

    /**
     * 下单量。用户通过该广告进行商品成交（如下单提交、在线支付）的次数。接入转化跟踪后可统计。
     */
    @SerializedName("order_count_minute")
    private Long orderCountMinute;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_total")
    private Long firstDayOrderCountTotal;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_day")
    private Long firstDayOrderCountDay;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_hour")
    private Long firstDayOrderCountHour;

    /**
     * 首日新增下单量。广告推广获取的用户，点击广告当日，带来的下单次数。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_count_minute")
    private Long firstDayOrderCountMinute;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_all")
    private Long webOrderCostAll;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_day")
    private Long webOrderCostDay;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_hour")
    private Long webOrderCostHour;

    /**
     * 下单成本（次数）。产生一次下单的成本。
     */
    @SerializedName("web_order_cost_minute")
    private Long webOrderCostMinute;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_all")
    private BigDecimal orderRateAll;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_day")
    private BigDecimal orderRateDay;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_hour")
    private BigDecimal orderRateHour;

    /**
     * 下单率。一次点击到下单的转化率。
     */
    @SerializedName("order_rate_minute")
    private BigDecimal orderRateMinute;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_total")
    private Long orderAmountTotal;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_day")
    private Long orderAmountDay;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_hour")
    private Long orderAmountHour;

    /**
     * 下单金额。广告带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("order_amount_minute")
    private Long orderAmountMinute;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_total")
    private Long firstDayOrderAmountTotal;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_day")
    private Long firstDayOrderAmountDay;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_hour")
    private Long firstDayOrderAmountHour;

    /**
     * 首日新增下单金额。广告推广获取的用户，点击广告当日，带来的总订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("first_day_order_amount_minute")
    private Long firstDayOrderAmountMinute;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_all")
    private Long orderUnitPriceAll;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_day")
    private Long orderUnitPriceDay;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_hour")
    private Long orderUnitPriceHour;

    /**
     * 下单客单价。下单金额/下单量。接入转化跟踪后可统计。
     */
    @SerializedName("order_unit_price_minute")
    private Long orderUnitPriceMinute;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_all")
    private BigDecimal orderRoiAll;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_day")
    private BigDecimal orderRoiDay;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_hour")
    private BigDecimal orderRoiHour;

    /**
     * 下单ROI。下单金额/广告花费。接入转化跟踪后可统计。
     */
    @SerializedName("order_roi_minute")
    private BigDecimal orderRoiMinute;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_total")
    private Long signInCountTotal;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_day")
    private Long signInCountDay;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_hour")
    private Long signInCountHour;

    /**
     * 签收次数。签收从广告主处购买的商品的次数。接入转化跟踪后可统计。
     */
    @SerializedName("sign_in_count_minute")
    private Long signInCountMinute;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_total")
    private Long scanFollowCountTotal;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_day")
    private Long scanFollowCountDay;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_hour")
    private Long scanFollowCountHour;

    /**
     * 加企业微信客服人数。添加企业微信好友成功的独立用户数。
     */
    @SerializedName("scan_follow_count_minute")
    private Long scanFollowCountMinute;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_total")
    private Long wechatAppRegisterUvTotal;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_day")
    private Long wechatAppRegisterUvDay;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_hour")
    private Long wechatAppRegisterUvHour;

    /**
     * 小游戏注册人数。通过广告首次登录小游戏的独立用户数。
     */
    @SerializedName("wechat_app_register_uv_minute")
    private Long wechatAppRegisterUvMinute;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_all")
    private Long wechatMinigameRegisterCostAll;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_day")
    private Long wechatMinigameRegisterCostDay;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_hour")
    private Long wechatMinigameRegisterCostHour;

    /**
     * 小游戏注册成本（人数）。产生一个小游戏注册人数的成本。
     */
    @SerializedName("wechat_minigame_register_cost_minute")
    private Long wechatMinigameRegisterCostMinute;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_all")
    private BigDecimal wechatMinigameRegisterRateAll;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_day")
    private BigDecimal wechatMinigameRegisterRateDay;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_hour")
    private BigDecimal wechatMinigameRegisterRateHour;

    /**
     * 小游戏注册率。一次点击到小游戏注册的转化率。
     */
    @SerializedName("wechat_minigame_register_rate_minute")
    private BigDecimal wechatMinigameRegisterRateMinute;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_all")
    private BigDecimal wechatMinigameArpuAll;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_day")
    private BigDecimal wechatMinigameArpuDay;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_hour")
    private BigDecimal wechatMinigameArpuHour;

    /**
     * 首日新增广告ARPU。广告带来的注册用户，在注册当日，产生的平均广告变现收入。注：该指标天更新，可以查看昨天及以前的数据。
     */
    @SerializedName("wechat_minigame_arpu_minute")
    private BigDecimal wechatMinigameArpuMinute;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_total")
    private Long wechatMinigameRetentionCountTotal;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_day")
    private Long wechatMinigameRetentionCountDay;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_hour")
    private Long wechatMinigameRetentionCountHour;

    /**
     * 小游戏次留人数。通过广告首次登录小游戏，并在第二天再次登录的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_retention_count_minute")
    private Long wechatMinigameRetentionCountMinute;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_total")
    private Long wechatMinigameCheckoutCountTotal;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_day")
    private Long wechatMinigameCheckoutCountDay;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_hour")
    private Long wechatMinigameCheckoutCountHour;

    /**
     * 小游戏付费次数。通过广告进入小游戏并完成付费的次数。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_count_minute")
    private Long wechatMinigameCheckoutCountMinute;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_total")
    private Long wechatMinigameCheckoutAmountTotal;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_day")
    private Long wechatMinigameCheckoutAmountDay;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_hour")
    private Long wechatMinigameCheckoutAmountHour;

    /**
     * 小游戏付费金额。通过广告进入小游戏并完成付费的金额。接入转化跟踪后可统计。
     */
    @SerializedName("wechat_minigame_checkout_amount_minute")
    private Long wechatMinigameCheckoutAmountMinute;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_total")
    private Long officialAccountFollowCountTotal;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_day")
    private Long officialAccountFollowCountDay;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_hour")
    private Long officialAccountFollowCountHour;

    /**
     * 公众号关注次数。用户通过广告关注公众号成功的次数。
     */
    @SerializedName("official_account_follow_count_minute")
    private Long officialAccountFollowCountMinute;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_all")
    private BigDecimal officialAccountFollowRateAll;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_day")
    private BigDecimal officialAccountFollowRateDay;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_hour")
    private BigDecimal officialAccountFollowRateHour;

    /**
     * 公众号关注率。一次点击到公众号关注的转化率。
     */
    @SerializedName("official_account_follow_rate_minute")
    private BigDecimal officialAccountFollowRateMinute;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_total")
    private Long officialAccountRegisterUserCountTotal;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_day")
    private Long officialAccountRegisterUserCountDay;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_hour")
    private Long officialAccountRegisterUserCountHour;

    /**
     * 公众号内注册人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的注册行为的人数（UV）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_user_count_minute")
    private Long officialAccountRegisterUserCountMinute;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_all")
    private BigDecimal officialAccountRegisterRateAll;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_day")
    private BigDecimal officialAccountRegisterRateDay;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_hour")
    private BigDecimal officialAccountRegisterRateHour;

    /**
     * 公众号内注册比例。公众号内注册独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_rate_minute")
    private BigDecimal officialAccountRegisterRateMinute;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_all")
    private Long officialAccountRegisterCostAll;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_day")
    private Long officialAccountRegisterCostDay;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_hour")
    private Long officialAccountRegisterCostHour;

    /**
     * 公众号内注册成本。广告花费/广告产生的注册行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_cost_minute")
    private Long officialAccountRegisterCostMinute;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_total")
    private Long officialAccountRegisterAmountTotal;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_day")
    private Long officialAccountRegisterAmountDay;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_hour")
    private Long officialAccountRegisterAmountHour;

    /**
     * 公众号内注册订单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的订单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_amount_minute")
    private Long officialAccountRegisterAmountMinute;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_all")
    private Long officialAccountRegisterRoiAll;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_day")
    private Long officialAccountRegisterRoiDay;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_hour")
    private Long officialAccountRegisterRoiHour;

    /**
     * 公众号内注册ROI。注册产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_register_roi_minute")
    private Long officialAccountRegisterRoiMinute;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_total")
    private Long officialAccountApplyCountTotal;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_day")
    private Long officialAccountApplyCountDay;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_hour")
    private Long officialAccountApplyCountHour;

    /**
     * 公众号内填单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_count_minute")
    private Long officialAccountApplyCountMinute;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_total")
    private Long officialAccountApplyUserCountTotal;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_day")
    private Long officialAccountApplyUserCountDay;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_hour")
    private Long officialAccountApplyUserCountHour;

    /**
     * 公众号内填单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_user_count_minute")
    private Long officialAccountApplyUserCountMinute;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_all")
    private BigDecimal officialAccountApplyRateAll;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_day")
    private BigDecimal officialAccountApplyRateDay;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_hour")
    private BigDecimal officialAccountApplyRateHour;

    /**
     * 公众号内填单比例。公众号内填单的独立用户数/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_rate_minute")
    private BigDecimal officialAccountApplyRateMinute;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_all")
    private Long officialAccountApplyCostAll;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_day")
    private Long officialAccountApplyCostDay;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_hour")
    private Long officialAccountApplyCostHour;

    /**
     * 公众号内填单成本。广告花费/广告产生的填单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_cost_minute")
    private Long officialAccountApplyCostMinute;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_total")
    private Long officialAccountApplyAmountTotal;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_day")
    private Long officialAccountApplyAmountDay;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_hour")
    private Long officialAccountApplyAmountHour;

    /**
     * 公众号内填单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的填单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放)。
     */
    @SerializedName("official_account_apply_amount_minute")
    private Long officialAccountApplyAmountMinute;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_all")
    private Long officialAccountApplyRoiAll;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_day")
    private Long officialAccountApplyRoiDay;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_hour")
    private Long officialAccountApplyRoiHour;

    /**
     * 公众号内填单ROI。填单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_apply_roi_minute")
    private Long officialAccountApplyRoiMinute;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_total")
    private Long officialAccountOrderCountTotal;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_day")
    private Long officialAccountOrderCountDay;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_hour")
    private Long officialAccountOrderCountHour;

    /**
     * 公众号内下单次数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_count_minute")
    private Long officialAccountOrderCountMinute;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_total")
    private Long officialAccountFirstDayOrderCountTotal;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_day")
    private Long officialAccountFirstDayOrderCountDay;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_hour")
    private Long officialAccountFirstDayOrderCountHour;

    /**
     * 首日公众号内下单次数。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为数量。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_count_minute")
    private Long officialAccountFirstDayOrderCountMinute;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_total")
    private Long officialAccountOrderUserCountTotal;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_day")
    private Long officialAccountOrderUserCountDay;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_hour")
    private Long officialAccountOrderUserCountHour;

    /**
     * 公众号内下单人数。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的独立用户数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_user_count_minute")
    private Long officialAccountOrderUserCountMinute;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_all")
    private BigDecimal officialAccountOrderRateAll;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_day")
    private BigDecimal officialAccountOrderRateDay;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_hour")
    private BigDecimal officialAccountOrderRateHour;

    /**
     * 公众号内下单比例。公众号内下单独立用户数（UV）/公众号关注次数。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_rate_minute")
    private BigDecimal officialAccountOrderRateMinute;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_all")
    private Long officialAccountOrderCostAll;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_day")
    private Long officialAccountOrderCostDay;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_hour")
    private Long officialAccountOrderCostHour;

    /**
     * 公众号内下单成本。广告花费/广告产生的下单行为数量。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_cost_minute")
    private Long officialAccountOrderCostMinute;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_total")
    private Long officialAccountOrderAmountTotal;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_day")
    private Long officialAccountOrderAmountDay;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_hour")
    private Long officialAccountOrderAmountHour;

    /**
     * 公众号内下单金额。用户通过关注类广告关注公众号后，在公众号内部产生了广告主定义的下单行为的订单金额（即销售额）。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_amount_minute")
    private Long officialAccountOrderAmountMinute;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_total")
    private Long officialAccountFirstDayOrderAmountTotal;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_day")
    private Long officialAccountFirstDayOrderAmountDay;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_hour")
    private Long officialAccountFirstDayOrderAmountHour;

    /**
     * 首日公众号内下单金额。广告推广获取的用户，在关注公众号当日，在公众号内部产生了广告主定义的下单行为订单金额（即销售额）。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_first_day_order_amount_minute")
    private Long officialAccountFirstDayOrderAmountMinute;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_all")
    private Long officialAccountOrderRoiAll;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_day")
    private Long officialAccountOrderRoiDay;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_hour")
    private Long officialAccountOrderRoiHour;

    /**
     * 公众号内下单ROI。下单产生的订单金额累计/广告花费。接入转化跟踪后可统计(公众号接入暂未全量开放) 。
     */
    @SerializedName("official_account_order_roi_minute")
    private Long officialAccountOrderRoiMinute;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_total")
    private Long officialAccountConsultCountTotal;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_day")
    private Long officialAccountConsultCountDay;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_hour")
    private Long officialAccountConsultCountHour;

    /**
     * 公众号内发消息人数。用户关注公众号后，在公众号对话框内发送消息的独立用户数。
     */
    @SerializedName("official_account_consult_count_minute")
    private Long officialAccountConsultCountMinute;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_total")
    private Long officialAccountReaderCountTotal;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_day")
    private Long officialAccountReaderCountDay;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_hour")
    private Long officialAccountReaderCountHour;

    /**
     * 阅读粉丝量。近3日新增的粉丝中产生阅读行为的用户数。
     */
    @SerializedName("official_account_reader_count_minute")
    private Long officialAccountReaderCountMinute;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_total")
    private Long officialAccountCreditApplyUserCountTotal;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_day")
    private Long officialAccountCreditApplyUserCountDay;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_hour")
    private Long officialAccountCreditApplyUserCountHour;

    /**
     * 公众号内进件人数。在公众号内完整提交贷款申请资料的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_apply_user_count_minute")
    private Long officialAccountCreditApplyUserCountMinute;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_total")
    private Long officialAccountCreditUserCountTotal;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_day")
    private Long officialAccountCreditUserCountDay;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_hour")
    private Long officialAccountCreditUserCountHour;

    /**
     * 公众号内授信人数。在公众号内完整提交贷款申请资料，并通过放款方的资质审核的独立用户数。接入转化跟踪后可统计。
     */
    @SerializedName("official_account_credit_user_count_minute")
    private Long officialAccountCreditUserCountMinute;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_total")
    private Long forwardCountTotal;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_day")
    private Long forwardCountDay;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_hour")
    private Long forwardCountHour;

    /**
     * 广告分享次数。用户将广告落地页分享给好友和朋友圈的次数。
     */
    @SerializedName("forward_count_minute")
    private Long forwardCountMinute;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_total")
    private Long forwardUserCountTotal;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_day")
    private Long forwardUserCountDay;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_hour")
    private Long forwardUserCountHour;

    /**
     * 广告分享人数。将广告落地页分享给好友和朋友圈的独立用户数。
     */
    @SerializedName("forward_user_count_minute")
    private Long forwardUserCountMinute;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_total")
    private Long noInterestCountTotal;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_day")
    private Long noInterestCountDay;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_hour")
    private Long noInterestCountHour;

    /**
     * 不感兴趣点击次数。用户点击“不感兴趣”的次数。
     */
    @SerializedName("no_interest_count_minute")
    private Long noInterestCountMinute;

    /**
     * 聚合
     *
     * @param beforeYesterdayDayDWD 广告前天（包括前天）聚合的天数据（用来计算总数据）
     * @param yesterdayMinuteDWD    昨天聚合的数据
     * @param todayODSList          当前待聚合的数据（当天数据列表）
     * @param statODS
     * @return
     */
    public static PlanStatOfMinuteDWD reduce(PlanStatOfDayDWD beforeYesterdayDayDWD, PlanStatOfMinuteDWD yesterdayMinuteDWD, List<AdDataOfMinuteODS> todayODSList, AdDataOfMinuteODS statODS, PlanStatOfMinuteDWD lastMinuteDWD, long createTime) {
        PlanStatOfMinuteDWD result = new PlanStatOfMinuteDWD();
        BeanUtils.copyProperties(statODS, result);
        result = initValue(result);
        result.setCreateTime(new Date(createTime));

        Map<Long, Set<Long>> adGroupMap = new HashMap<>();
        Set<Long> adIdsTemp = new HashSet<>(3);
        adIdsTemp.add(statODS.getAdId());
        adGroupMap.put(statODS.getAdgroupId(), adIdsTemp);
        result.setAdGroupMap(adGroupMap);

        Set<Long> adIds = new HashSet<>(3);
        adIds.add(statODS.getAdId());
        result.setAdIds(adIds);

        // 填充小时数据
        result.setCostDeviationRateHour(statODS.getCostDeviationRate());
        result.setCostHour(statODS.getCost());
        result.setCompensationAmountHour(statODS.getCompensationAmount());
        result.setViewCountHour(statODS.getViewCount());
        result.setThousandDisplayPriceHour(statODS.getThousandDisplayPrice());
        result.setAvgViewPerUserHour(statODS.getAvgViewPerUser());
        result.setValidClickCountHour(statODS.getValidClickCount());
        result.setCtrHour(statODS.getCtr());
        result.setCpcHour(statODS.getCpc());
        result.setValuableClickCountHour(statODS.getValuableClickCount());
        result.setValuableClickRateHour(statODS.getValuableClickRate());
        result.setValuableClickCostHour(statODS.getValuableClickCost());
        result.setConversionsCountHour(statODS.getConversionsCount());
        result.setConversionsCostHour(statODS.getConversionsCost());
        result.setConversionsRateHour(statODS.getConversionsRate());
        result.setDeepConversionsCountHour(statODS.getDeepConversionsCount());
        result.setDeepConversionsCostHour(statODS.getDeepConversionsCost());
        result.setDeepConversionsRateHour(statODS.getDeepConversionsRate());
        result.setOrderCountHour(statODS.getOrderCount());
        result.setFirstDayOrderCountHour(statODS.getFirstDayOrderCount());
        result.setWebOrderCostHour(statODS.getWebOrderCost());
        result.setOrderRateHour(statODS.getOrderRate());
        result.setOrderAmountHour(statODS.getOrderAmount());
        result.setFirstDayOrderAmountHour(statODS.getFirstDayOrderAmount());
        result.setOrderUnitPriceHour(statODS.getOrderUnitPrice());
        result.setOrderRoiHour(statODS.getOrderRoi());
        result.setSignInCountHour(statODS.getSignInCount());
        result.setScanFollowCountHour(statODS.getScanFollowCount());
        result.setWechatAppRegisterUvHour(statODS.getWechatAppRegisterUv());
        result.setWechatMinigameRegisterCostHour(statODS.getWechatMinigameRegisterCost());
        result.setWechatMinigameRegisterRateHour(statODS.getWechatMinigameRegisterRate());
        result.setWechatMinigameArpuHour(statODS.getWechatMinigameArpu());
        result.setWechatMinigameRetentionCountHour(statODS.getWechatMinigameRetentionCount());
        result.setWechatMinigameCheckoutCountHour(statODS.getWechatMinigameCheckoutCount());
        result.setWechatMinigameCheckoutAmountHour(statODS.getWechatMinigameCheckoutAmount());
        result.setOfficialAccountFollowCountHour(statODS.getOfficialAccountFollowCount());
        result.setOfficialAccountFollowRateHour(statODS.getOfficialAccountFollowRate());
        result.setOfficialAccountRegisterUserCountHour(statODS.getOfficialAccountRegisterUserCount());
        result.setOfficialAccountRegisterRateHour(statODS.getOfficialAccountRegisterRate());
        result.setOfficialAccountRegisterCostHour(statODS.getOfficialAccountRegisterCost());
        result.setOfficialAccountRegisterAmountHour(statODS.getOfficialAccountRegisterAmount());
        result.setOfficialAccountRegisterRoiHour(statODS.getOfficialAccountRegisterRoi());
        result.setOfficialAccountApplyCountHour(statODS.getOfficialAccountApplyCount());
        result.setOfficialAccountApplyUserCountHour(statODS.getOfficialAccountApplyUserCount());
        result.setOfficialAccountApplyRateHour(statODS.getOfficialAccountApplyRate());
        result.setOfficialAccountApplyCostHour(statODS.getOfficialAccountApplyCost());
        result.setOfficialAccountApplyAmountHour(statODS.getOfficialAccountApplyAmount());
        result.setOfficialAccountApplyRoiHour(statODS.getOfficialAccountApplyRoi());
        result.setOfficialAccountOrderCountHour(statODS.getOfficialAccountOrderCount());
        result.setOfficialAccountFirstDayOrderCountHour(statODS.getOfficialAccountFirstDayOrderCount());
        result.setOfficialAccountOrderUserCountHour(statODS.getOfficialAccountOrderUserCount());
        result.setOfficialAccountOrderRateHour(statODS.getOfficialAccountOrderRate());
        result.setOfficialAccountOrderCostHour(statODS.getOfficialAccountOrderCost());
        result.setOfficialAccountOrderAmountHour(statODS.getOfficialAccountOrderAmount());
        result.setOfficialAccountFirstDayOrderAmountHour(statODS.getOfficialAccountFirstDayOrderAmount());
        result.setOfficialAccountOrderRoiHour(statODS.getOfficialAccountOrderRoi());
        result.setOfficialAccountConsultCountHour(statODS.getOfficialAccountConsultCount());
        result.setOfficialAccountReaderCountHour(statODS.getOfficialAccountReaderCount());
        result.setOfficialAccountCreditApplyUserCountHour(statODS.getOfficialAccountCreditApplyUserCount());
        result.setOfficialAccountCreditUserCountHour(statODS.getOfficialAccountCreditUserCount());
        result.setForwardCountHour(statODS.getForwardCount());
        result.setForwardUserCountHour(statODS.getForwardUserCount());
        result.setNoInterestCountHour(statODS.getNoInterestCount());
        // 聚合当天的数据
        for (AdDataOfMinuteODS todayODS : todayODSList) {
            result.getAdIds().add(todayODS.getAdId());
            result.getAdGroupMap().computeIfAbsent(todayODS.getAdgroupId(), key -> new HashSet<>(3)).add(todayODS.getAdId());

            result.setCostDeviationRateDay(result.getCostDeviationRateDay().add(todayODS.getCostDeviationRate()));
            result.setCostDay(result.getCostDay() + todayODS.getCost());
            result.setCompensationAmountDay(result.getCompensationAmountDay() + todayODS.getCompensationAmount());
            result.setViewCountDay(result.getViewCountDay() + todayODS.getViewCount());
            result.setValidClickCountDay(result.getValidClickCountDay() + todayODS.getValidClickCount());
            result.setValuableClickCountDay(result.getValuableClickCountDay() + todayODS.getValuableClickCount());
            result.setConversionsCountDay(result.getConversionsCountDay() + todayODS.getConversionsCount());
            result.setDeepConversionsCountDay(result.getDeepConversionsCountDay() + todayODS.getDeepConversionsCount());
            result.setOrderCountDay(result.getOrderCountDay() + todayODS.getOrderCount());
            result.setFirstDayOrderCountDay(result.getFirstDayOrderCountDay() + todayODS.getFirstDayOrderCount());
            result.setOrderAmountDay(result.getOrderAmountDay() + todayODS.getOrderAmount());
            result.setFirstDayOrderAmountDay(result.getFirstDayOrderAmountDay() + todayODS.getFirstDayOrderAmount());
            result.setSignInCountDay(result.getSignInCountDay() + todayODS.getSignInCount());
            result.setScanFollowCountDay(result.getScanFollowCountDay() + todayODS.getScanFollowCount());
            result.setWechatAppRegisterUvDay(result.getWechatAppRegisterUvDay() + todayODS.getWechatAppRegisterUv());
            result.setWechatMinigameRetentionCountDay(result.getWechatMinigameRetentionCountDay() + todayODS.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountDay(result.getWechatMinigameCheckoutCountDay() + todayODS.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountDay(result.getWechatMinigameCheckoutAmountDay() + todayODS.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountDay(result.getOfficialAccountFollowCountDay() + todayODS.getOfficialAccountFollowCount());
            result.setOfficialAccountRegisterUserCountDay(result.getOfficialAccountRegisterUserCountDay() + todayODS.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterAmountDay(result.getOfficialAccountRegisterAmountDay() + todayODS.getOfficialAccountRegisterAmount());
            result.setOfficialAccountApplyCountDay(result.getOfficialAccountApplyCountDay() + todayODS.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountDay(result.getOfficialAccountApplyUserCountDay() + todayODS.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyAmountDay(result.getOfficialAccountApplyAmountDay() + todayODS.getOfficialAccountApplyAmount());
            result.setOfficialAccountOrderCountDay(result.getOfficialAccountOrderCountDay() + todayODS.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountDay(result.getOfficialAccountFirstDayOrderCountDay() + todayODS.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountDay(result.getOfficialAccountOrderUserCountDay() + todayODS.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderAmountDay(result.getOfficialAccountOrderAmountDay() + todayODS.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountDay(result.getOfficialAccountFirstDayOrderAmountDay() + todayODS.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountConsultCountDay(result.getOfficialAccountConsultCountDay() + todayODS.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountDay(result.getOfficialAccountReaderCountDay() + todayODS.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountDay(result.getOfficialAccountCreditApplyUserCountDay() + todayODS.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountDay(result.getOfficialAccountCreditUserCountDay() + todayODS.getOfficialAccountCreditUserCount());
            result.setForwardCountDay(result.getForwardCountDay() + todayODS.getForwardCount());
            result.setForwardUserCountDay(result.getForwardUserCountDay() + todayODS.getForwardUserCount());
            result.setNoInterestCountDay(result.getNoInterestCountDay() + todayODS.getNoInterestCount());

            // 总消耗 / 总曝光
            result.setThousandDisplayPriceDay(result.getViewCountDay() == 0 ? 0 : NumberUtil.divideForAd(result.getCostDay(), result.getViewCountDay()).multiply(new BigDecimal(1000)).longValue());
            // 广告点击次数 / 广告曝光次数
            result.setCtrDay(result.getViewCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValidClickCountDay(), result.getViewCountDay()));
            // 广告花费/广告点击次数
            result.setCpcDay(result.getValidClickCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getValidClickCountDay()));
            // 广告可转化点击次数/广告曝光次数
            result.setValuableClickRateDay(result.getViewCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValuableClickCountDay(), result.getViewCountDay()));
            // 广告花费/可转化点击次数
            result.setValuableClickCostDay(result.getValuableClickCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getValuableClickCountDay()));
            // 广告花费/转化目标量
            result.setConversionsCostDay(result.getConversionsCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getConversionsCountDay()));
            // 公众号：转化目标量/点击次数。
            result.setConversionsRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getConversionsCountDay(), result.getValidClickCountDay()));
            // 广告花费/深度转化目标量
            result.setDeepConversionsCostDay(result.getDeepConversionsCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getDeepConversionsCountDay()));
            // 深度转化目标量/可转化点击次数
            result.setDeepConversionsRateDay(result.getValuableClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getDeepConversionsCountDay(), result.getValuableClickCountDay()));
            // 广告花费/下单量
            result.setWebOrderCostDay(result.getOrderCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOrderCountDay()));
            // 下单量/点击次数
            result.setOrderRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderCountDay(), result.getValidClickCountDay()));
            // 下单金额/下单量
            result.setOrderUnitPriceDay(result.getOrderCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOrderAmountDay(), result.getOrderCountDay()));
            // 下单金额/广告花费
            result.setOrderRoiDay(result.getCostDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountDay(), result.getCostDay()));
            // 广告消耗 / 小游戏注册人数
            result.setWechatMinigameRegisterCostDay(result.getWechatAppRegisterUvDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getWechatAppRegisterUvDay()));
            // 小游戏注册人数 / 广告点击次数
            result.setWechatMinigameRegisterRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getWechatAppRegisterUvDay(), result.getValidClickCountDay()));
            // 总收益 / 总人数
            result.setWechatMinigameArpuDay(result.getWechatAppRegisterUvDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountDay(), result.getWechatAppRegisterUvDay()));
            // 关注次数 / 点击次数
            result.setOfficialAccountFollowRateDay(result.getValidClickCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountFollowCountDay(), result.getValidClickCountDay()));
            // 公众号内注册人数 / 公众号关注次数
            result.setOfficialAccountRegisterRateDay(result.getOfficialAccountFollowCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountDay(), result.getOfficialAccountFollowCountDay()));
            // 广告消耗 / 广告注册人数
            result.setOfficialAccountRegisterCostDay(result.getOfficialAccountRegisterUserCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountRegisterUserCountDay()));
            // 注册产生的订单金额累计/广告花费
            result.setOfficialAccountRegisterRoiDay(result.getCostDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountDay(), result.getCostDay()));
            // 公众号内填单的独立用户数/公众号关注次数
            result.setOfficialAccountApplyRateDay(result.getOfficialAccountFollowCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountDay(), result.getOfficialAccountFollowCountDay()));
            // 广告花费/广告产生的填单行为数量
            result.setOfficialAccountApplyCostDay(result.getOfficialAccountApplyUserCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountApplyUserCountDay()));
            // 填单产生的订单金额累计/广告花费
            result.setOfficialAccountApplyRoiDay(result.getCostDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountDay(), result.getCostDay()));
            // 公众号内下单独立用户数（UV）/公众号关注次数
            result.setOfficialAccountOrderRateDay(result.getOfficialAccountFollowCountDay() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountDay(), result.getOfficialAccountFollowCountDay()));
            // 广告花费/广告产生的下单行为数量
            result.setOfficialAccountOrderCostDay(result.getOfficialAccountOrderCountDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostDay(), result.getOfficialAccountOrderCountDay()));
            // 下单产生的订单金额累计/广告花费
            result.setOfficialAccountOrderRoiDay(result.getCostDay() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountDay(), result.getCostDay()));
        }
        // 填充总数据
        if (beforeYesterdayDayDWD != null) {
            result.getAdIds().addAll(beforeYesterdayDayDWD.getAdIds());
            PlanUtil.reduceAdGroup(result.getAdGroupMap(), beforeYesterdayDayDWD.getAdGroupMap());

            result.setCostDeviationRateTotal(beforeYesterdayDayDWD.getCostDeviationRateTotal());
            result.setCostTotal(beforeYesterdayDayDWD.getCostTotal());
            result.setCompensationAmountTotal(beforeYesterdayDayDWD.getCompensationAmountTotal());
            result.setViewCountTotal(beforeYesterdayDayDWD.getViewCountTotal());
            result.setThousandDisplayPriceAll(beforeYesterdayDayDWD.getThousandDisplayPriceAll());
            result.setAvgViewPerUserAll(beforeYesterdayDayDWD.getAvgViewPerUserAll());
            result.setValidClickCountTotal(beforeYesterdayDayDWD.getValidClickCountTotal());
            result.setCtrAll(beforeYesterdayDayDWD.getCtrAll());
            result.setCpcAll(beforeYesterdayDayDWD.getCpcAll());
            result.setValuableClickCountTotal(beforeYesterdayDayDWD.getValuableClickCountTotal());
            result.setValuableClickRateAll(beforeYesterdayDayDWD.getValuableClickRateAll());
            result.setValuableClickCostAll(beforeYesterdayDayDWD.getValuableClickCostAll());
            result.setConversionsCountTotal(beforeYesterdayDayDWD.getConversionsCountTotal());
            result.setConversionsCostAll(beforeYesterdayDayDWD.getConversionsCostAll());
            result.setConversionsRateAll(beforeYesterdayDayDWD.getConversionsRateAll());
            result.setDeepConversionsCountTotal(beforeYesterdayDayDWD.getDeepConversionsCountTotal());
            result.setDeepConversionsCostAll(beforeYesterdayDayDWD.getDeepConversionsCostAll());
            result.setDeepConversionsRateAll(beforeYesterdayDayDWD.getDeepConversionsRateAll());
            result.setOrderCountTotal(beforeYesterdayDayDWD.getOrderCountTotal());
            result.setFirstDayOrderCountTotal(beforeYesterdayDayDWD.getFirstDayOrderCountTotal());
            result.setWebOrderCostAll(beforeYesterdayDayDWD.getWebOrderCostAll());
            result.setOrderRateAll(beforeYesterdayDayDWD.getOrderRateAll());
            result.setOrderAmountTotal(beforeYesterdayDayDWD.getOrderAmountTotal());
            result.setFirstDayOrderAmountTotal(beforeYesterdayDayDWD.getFirstDayOrderAmountTotal());
            result.setOrderUnitPriceAll(beforeYesterdayDayDWD.getOrderUnitPriceAll());
            result.setOrderRoiAll(beforeYesterdayDayDWD.getOrderRoiAll());
            result.setSignInCountTotal(beforeYesterdayDayDWD.getSignInCountTotal());
            result.setScanFollowCountTotal(beforeYesterdayDayDWD.getScanFollowCountTotal());
            result.setWechatAppRegisterUvTotal(beforeYesterdayDayDWD.getWechatAppRegisterUvTotal());
            result.setWechatMinigameRegisterCostAll(beforeYesterdayDayDWD.getWechatMinigameRegisterCostAll());
            result.setWechatMinigameRegisterRateAll(beforeYesterdayDayDWD.getWechatMinigameRegisterRateAll());
            result.setWechatMinigameArpuAll(beforeYesterdayDayDWD.getWechatMinigameArpuAll());
            result.setWechatMinigameRetentionCountTotal(beforeYesterdayDayDWD.getWechatMinigameRetentionCountTotal());
            result.setWechatMinigameCheckoutCountTotal(beforeYesterdayDayDWD.getWechatMinigameCheckoutCountTotal());
            result.setWechatMinigameCheckoutAmountTotal(beforeYesterdayDayDWD.getWechatMinigameCheckoutAmountTotal());
            result.setOfficialAccountFollowCountTotal(beforeYesterdayDayDWD.getOfficialAccountFollowCountTotal());
            result.setOfficialAccountFollowRateAll(beforeYesterdayDayDWD.getOfficialAccountFollowRateAll());
            result.setOfficialAccountRegisterUserCountTotal(beforeYesterdayDayDWD.getOfficialAccountRegisterUserCountTotal());
            result.setOfficialAccountRegisterRateAll(beforeYesterdayDayDWD.getOfficialAccountRegisterRateAll());
            result.setOfficialAccountRegisterCostAll(beforeYesterdayDayDWD.getOfficialAccountRegisterCostAll());
            result.setOfficialAccountRegisterAmountTotal(beforeYesterdayDayDWD.getOfficialAccountRegisterAmountTotal());
            result.setOfficialAccountRegisterRoiAll(beforeYesterdayDayDWD.getOfficialAccountRegisterRoiAll());
            result.setOfficialAccountApplyCountTotal(beforeYesterdayDayDWD.getOfficialAccountApplyCountTotal());
            result.setOfficialAccountApplyUserCountTotal(beforeYesterdayDayDWD.getOfficialAccountApplyUserCountTotal());
            result.setOfficialAccountApplyRateAll(beforeYesterdayDayDWD.getOfficialAccountApplyRateAll());
            result.setOfficialAccountApplyCostAll(beforeYesterdayDayDWD.getOfficialAccountApplyCostAll());
            result.setOfficialAccountApplyAmountTotal(beforeYesterdayDayDWD.getOfficialAccountApplyAmountTotal());
            result.setOfficialAccountApplyRoiAll(beforeYesterdayDayDWD.getOfficialAccountApplyRoiAll());
            result.setOfficialAccountOrderCountTotal(beforeYesterdayDayDWD.getOfficialAccountOrderCountTotal());
            result.setOfficialAccountFirstDayOrderCountTotal(beforeYesterdayDayDWD.getOfficialAccountFirstDayOrderCountTotal());
            result.setOfficialAccountOrderUserCountTotal(beforeYesterdayDayDWD.getOfficialAccountOrderUserCountTotal());
            result.setOfficialAccountOrderRateAll(beforeYesterdayDayDWD.getOfficialAccountOrderRateAll());
            result.setOfficialAccountOrderCostAll(beforeYesterdayDayDWD.getOfficialAccountOrderCostAll());
            result.setOfficialAccountOrderAmountTotal(beforeYesterdayDayDWD.getOfficialAccountOrderAmountTotal());
            result.setOfficialAccountFirstDayOrderAmountTotal(beforeYesterdayDayDWD.getOfficialAccountFirstDayOrderAmountTotal());
            result.setOfficialAccountOrderRoiAll(beforeYesterdayDayDWD.getOfficialAccountOrderRoiAll());
            result.setOfficialAccountConsultCountTotal(beforeYesterdayDayDWD.getOfficialAccountConsultCountTotal());
            result.setOfficialAccountReaderCountTotal(beforeYesterdayDayDWD.getOfficialAccountReaderCountTotal());
            result.setOfficialAccountCreditApplyUserCountTotal(beforeYesterdayDayDWD.getOfficialAccountCreditApplyUserCountTotal());
            result.setOfficialAccountCreditUserCountTotal(beforeYesterdayDayDWD.getOfficialAccountCreditUserCountTotal());
            result.setForwardCountTotal(beforeYesterdayDayDWD.getForwardCountTotal());
            result.setForwardUserCountTotal(beforeYesterdayDayDWD.getForwardUserCountTotal());
            result.setNoInterestCountTotal(beforeYesterdayDayDWD.getNoInterestCountTotal());
        }
        if (yesterdayMinuteDWD != null) {
            result.getAdIds().addAll(yesterdayMinuteDWD.getAdIds());
            PlanUtil.reduceAdGroup(result.getAdGroupMap(), yesterdayMinuteDWD.getAdGroupMap());

            result.setCostDeviationRateTotal(result.getCostDeviationRateTotal().add(yesterdayMinuteDWD.getCostDeviationRateDay()));
            result.setCostTotal(result.getCostTotal() + yesterdayMinuteDWD.getCostDay());
            result.setCompensationAmountTotal(result.getCompensationAmountTotal() + yesterdayMinuteDWD.getCompensationAmountDay());
            result.setViewCountTotal(result.getViewCountTotal() + yesterdayMinuteDWD.getViewCountDay());
            result.setValidClickCountTotal(result.getValidClickCountTotal() + yesterdayMinuteDWD.getValidClickCountDay());
            result.setValuableClickCountTotal(result.getValuableClickCountTotal() + yesterdayMinuteDWD.getValuableClickCountDay());
            result.setConversionsCountTotal(result.getConversionsCountTotal() + yesterdayMinuteDWD.getConversionsCountDay());
            result.setDeepConversionsCountTotal(result.getDeepConversionsCountTotal() + yesterdayMinuteDWD.getDeepConversionsCountDay());
            result.setOrderCountTotal(result.getOrderCountTotal() + yesterdayMinuteDWD.getOrderCountDay());
            result.setFirstDayOrderCountTotal(result.getFirstDayOrderCountTotal() + yesterdayMinuteDWD.getFirstDayOrderCountDay());
            result.setOrderAmountTotal(result.getOrderAmountTotal() + yesterdayMinuteDWD.getOrderAmountDay());
            result.setFirstDayOrderAmountTotal(result.getFirstDayOrderAmountTotal() + yesterdayMinuteDWD.getFirstDayOrderAmountDay());
            result.setSignInCountTotal(result.getSignInCountTotal() + yesterdayMinuteDWD.getSignInCountDay());
            result.setScanFollowCountTotal(result.getScanFollowCountTotal() + yesterdayMinuteDWD.getScanFollowCountDay());
            result.setWechatAppRegisterUvTotal(result.getWechatAppRegisterUvTotal() + yesterdayMinuteDWD.getWechatAppRegisterUvDay());
            result.setWechatMinigameRetentionCountTotal(result.getWechatMinigameRetentionCountTotal() + yesterdayMinuteDWD.getWechatMinigameRetentionCountDay());
            result.setWechatMinigameCheckoutCountTotal(result.getWechatMinigameCheckoutCountTotal() + yesterdayMinuteDWD.getWechatMinigameCheckoutCountDay());
            result.setWechatMinigameCheckoutAmountTotal(result.getWechatMinigameCheckoutAmountTotal() + yesterdayMinuteDWD.getWechatMinigameCheckoutAmountDay());
            result.setOfficialAccountFollowCountTotal(result.getOfficialAccountFollowCountTotal() + yesterdayMinuteDWD.getOfficialAccountFollowCountDay());
            result.setOfficialAccountRegisterUserCountTotal(result.getOfficialAccountRegisterUserCountTotal() + yesterdayMinuteDWD.getOfficialAccountRegisterUserCountDay());
            result.setOfficialAccountRegisterAmountTotal(result.getOfficialAccountRegisterAmountTotal() + yesterdayMinuteDWD.getOfficialAccountRegisterAmountDay());
            result.setOfficialAccountApplyCountTotal(result.getOfficialAccountApplyCountTotal() + yesterdayMinuteDWD.getOfficialAccountApplyCountDay());
            result.setOfficialAccountApplyUserCountTotal(result.getOfficialAccountApplyUserCountTotal() + yesterdayMinuteDWD.getOfficialAccountApplyUserCountDay());
            result.setOfficialAccountApplyAmountTotal(result.getOfficialAccountApplyAmountTotal() + yesterdayMinuteDWD.getOfficialAccountApplyAmountDay());
            result.setOfficialAccountOrderCountTotal(result.getOfficialAccountOrderCountTotal() + yesterdayMinuteDWD.getOfficialAccountOrderCountDay());
            result.setOfficialAccountFirstDayOrderCountTotal(result.getOfficialAccountFirstDayOrderCountTotal() + yesterdayMinuteDWD.getOfficialAccountFirstDayOrderCountDay());
            result.setOfficialAccountOrderUserCountTotal(result.getOfficialAccountOrderUserCountTotal() + yesterdayMinuteDWD.getOfficialAccountOrderUserCountDay());
            result.setOfficialAccountOrderAmountTotal(result.getOfficialAccountOrderAmountTotal() + yesterdayMinuteDWD.getOfficialAccountOrderAmountDay());
            result.setOfficialAccountFirstDayOrderAmountTotal(result.getOfficialAccountFirstDayOrderAmountTotal() + yesterdayMinuteDWD.getOfficialAccountFirstDayOrderAmountDay());
            result.setOfficialAccountConsultCountTotal(result.getOfficialAccountConsultCountTotal() + yesterdayMinuteDWD.getOfficialAccountConsultCountDay());
            result.setOfficialAccountReaderCountTotal(result.getOfficialAccountReaderCountTotal() + yesterdayMinuteDWD.getOfficialAccountReaderCountDay());
            result.setOfficialAccountCreditApplyUserCountTotal(result.getOfficialAccountCreditApplyUserCountTotal() + yesterdayMinuteDWD.getOfficialAccountCreditApplyUserCountDay());
            result.setOfficialAccountCreditUserCountTotal(result.getOfficialAccountCreditUserCountTotal() + yesterdayMinuteDWD.getOfficialAccountCreditUserCountDay());
            result.setForwardCountTotal(result.getForwardCountTotal() + yesterdayMinuteDWD.getForwardCountDay());
            result.setForwardUserCountTotal(result.getForwardUserCountTotal() + yesterdayMinuteDWD.getForwardUserCountDay());
            result.setNoInterestCountTotal(result.getNoInterestCountTotal() + yesterdayMinuteDWD.getNoInterestCountDay());
        }
        result.setCostDeviationRateTotal(result.getCostDeviationRateTotal().add(result.getCostDeviationRateDay()));
        result.setCostTotal(result.getCostTotal() + result.getCostDay());
        result.setCompensationAmountTotal(result.getCompensationAmountTotal() + result.getCompensationAmountDay());
        result.setViewCountTotal(result.getViewCountTotal() + result.getViewCountDay());
        result.setValidClickCountTotal(result.getValidClickCountTotal() + result.getValidClickCountDay());
        result.setValuableClickCountTotal(result.getValuableClickCountTotal() + result.getValuableClickCountDay());
        result.setConversionsCountTotal(result.getConversionsCountTotal() + result.getConversionsCountDay());
        result.setDeepConversionsCountTotal(result.getDeepConversionsCountTotal() + result.getDeepConversionsCountDay());
        result.setOrderCountTotal(result.getOrderCountTotal() + result.getOrderCountDay());
        result.setFirstDayOrderCountTotal(result.getFirstDayOrderCountTotal() + result.getFirstDayOrderCountDay());
        result.setOrderAmountTotal(result.getOrderAmountTotal() + result.getOrderAmountDay());
        result.setFirstDayOrderAmountTotal(result.getFirstDayOrderAmountTotal() + result.getFirstDayOrderAmountDay());
        result.setSignInCountTotal(result.getSignInCountTotal() + result.getSignInCountDay());
        result.setScanFollowCountTotal(result.getScanFollowCountTotal() + result.getScanFollowCountDay());
        result.setWechatAppRegisterUvTotal(result.getWechatAppRegisterUvTotal() + result.getWechatAppRegisterUvDay());
        result.setWechatMinigameRetentionCountTotal(result.getWechatMinigameRetentionCountTotal() + result.getWechatMinigameRetentionCountDay());
        result.setWechatMinigameCheckoutCountTotal(result.getWechatMinigameCheckoutCountTotal() + result.getWechatMinigameCheckoutCountDay());
        result.setWechatMinigameCheckoutAmountTotal(result.getWechatMinigameCheckoutAmountTotal() + result.getWechatMinigameCheckoutAmountDay());
        result.setOfficialAccountFollowCountTotal(result.getOfficialAccountFollowCountTotal() + result.getOfficialAccountFollowCountDay());
        result.setOfficialAccountRegisterUserCountTotal(result.getOfficialAccountRegisterUserCountTotal() + result.getOfficialAccountRegisterUserCountDay());
        result.setOfficialAccountRegisterAmountTotal(result.getOfficialAccountRegisterAmountTotal() + result.getOfficialAccountRegisterAmountDay());
        result.setOfficialAccountApplyCountTotal(result.getOfficialAccountApplyCountTotal() + result.getOfficialAccountApplyCountDay());
        result.setOfficialAccountApplyUserCountTotal(result.getOfficialAccountApplyUserCountTotal() + result.getOfficialAccountApplyUserCountDay());
        result.setOfficialAccountOrderCountTotal(result.getOfficialAccountOrderCountTotal() + result.getOfficialAccountOrderCountDay());
        result.setOfficialAccountFirstDayOrderCountTotal(result.getOfficialAccountFirstDayOrderCountTotal() + result.getOfficialAccountFirstDayOrderCountDay());
        result.setOfficialAccountOrderUserCountTotal(result.getOfficialAccountOrderUserCountTotal() + result.getOfficialAccountOrderUserCountDay());
        result.setOfficialAccountApplyAmountTotal(result.getOfficialAccountApplyAmountTotal() + result.getOfficialAccountApplyAmountDay());
        result.setOfficialAccountOrderAmountTotal(result.getOfficialAccountOrderAmountTotal() + result.getOfficialAccountOrderAmountDay());
        result.setOfficialAccountFirstDayOrderAmountTotal(result.getOfficialAccountFirstDayOrderAmountTotal() + result.getOfficialAccountFirstDayOrderAmountDay());
        result.setOfficialAccountConsultCountTotal(result.getOfficialAccountConsultCountTotal() + result.getOfficialAccountConsultCountDay());
        result.setOfficialAccountReaderCountTotal(result.getOfficialAccountReaderCountTotal() + result.getOfficialAccountReaderCountDay());
        result.setOfficialAccountCreditApplyUserCountTotal(result.getOfficialAccountCreditApplyUserCountTotal() + result.getOfficialAccountCreditApplyUserCountDay());
        result.setOfficialAccountCreditUserCountTotal(result.getOfficialAccountCreditUserCountTotal() + result.getOfficialAccountCreditUserCountDay());
        result.setForwardCountTotal(result.getForwardCountTotal() + result.getForwardCountDay());
        result.setForwardUserCountTotal(result.getForwardUserCountTotal() + result.getForwardUserCountDay());
        result.setNoInterestCountTotal(result.getNoInterestCountTotal() + result.getNoInterestCountDay());
        // 总消耗 / 总曝光
        result.setThousandDisplayPriceAll(result.getViewCountTotal() == 0 ? 0 : NumberUtil.divideForAd(result.getCostTotal(), result.getViewCountTotal()).multiply(new BigDecimal(1000)).longValue());
        // 广告点击次数 / 广告曝光次数
        result.setCtrAll(result.getViewCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValidClickCountTotal(), result.getViewCountTotal()));
        // 广告花费/广告点击次数
        result.setCpcAll(result.getValidClickCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getValidClickCountTotal()));
        // 广告可转化点击次数/广告曝光次数
        result.setValuableClickRateAll(result.getViewCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValuableClickCountTotal(), result.getViewCountTotal()));
        // 广告花费/可转化点击次数
        result.setValuableClickCostAll(result.getValuableClickCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getValuableClickCountTotal()));
        // 广告花费/转化目标量
        result.setConversionsCostAll(result.getConversionsCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getConversionsCountTotal()));
        // 公众号：转化目标量/点击次数。
        result.setConversionsRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getConversionsCountTotal(), result.getValidClickCountTotal()));
        // 广告花费/深度转化目标量
        result.setDeepConversionsCostAll(result.getDeepConversionsCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getDeepConversionsCountTotal()));
        // 深度转化目标量/可转化点击次数
        result.setDeepConversionsRateAll(result.getValuableClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getDeepConversionsCountTotal(), result.getValuableClickCountTotal()));
        // 广告花费/下单量
        result.setWebOrderCostAll(result.getOrderCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOrderCountTotal()));
        // 下单量/点击次数
        result.setOrderRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderCountTotal(), result.getValidClickCountTotal()));
        // 下单金额/下单量
        result.setOrderUnitPriceAll(result.getOrderCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOrderAmountTotal(), result.getOrderCountTotal()));
        // 下单金额/广告花费
        result.setOrderRoiAll(result.getCostTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountTotal(), result.getCostTotal()));
        // 广告消耗 / 小游戏注册人数
        result.setWechatMinigameRegisterCostAll(result.getWechatAppRegisterUvTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getWechatAppRegisterUvTotal()));
        // 小游戏注册人数 / 广告点击次数
        result.setWechatMinigameRegisterRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getWechatAppRegisterUvTotal(), result.getValidClickCountTotal()));
        // 总收益 / 总人数
        result.setWechatMinigameArpuAll(result.getWechatAppRegisterUvTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountTotal(), result.getWechatAppRegisterUvTotal()));
        // 关注次数 / 点击次数
        result.setOfficialAccountFollowRateAll(result.getValidClickCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountFollowCountTotal(), result.getValidClickCountTotal()));
        // 公众号内注册人数 / 公众号关注次数
        result.setOfficialAccountRegisterRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
        // 广告消耗 / 广告注册人数
        result.setOfficialAccountRegisterCostAll(result.getOfficialAccountRegisterUserCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountRegisterUserCountTotal()));
        // 注册产生的订单金额累计/广告花费
        result.setOfficialAccountRegisterRoiAll(result.getCostTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountTotal(), result.getCostTotal()));
        // 公众号内填单的独立用户数/公众号关注次数
        result.setOfficialAccountApplyRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
        // 广告花费/广告产生的填单行为数量
        result.setOfficialAccountApplyCostAll(result.getOfficialAccountApplyUserCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountApplyUserCountTotal()));
        // 填单产生的订单金额累计/广告花费
        result.setOfficialAccountApplyRoiAll(result.getCostTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountTotal(), result.getCostTotal()));
        // 公众号内下单独立用户数（UV）/公众号关注次数
        result.setOfficialAccountOrderRateAll(result.getOfficialAccountFollowCountTotal() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountTotal(), result.getOfficialAccountFollowCountTotal()));
        // 广告花费/广告产生的下单行为数量
        result.setOfficialAccountOrderCostAll(result.getOfficialAccountOrderCountTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostTotal(), result.getOfficialAccountOrderCountTotal()));
        // 下单产生的订单金额累计/广告花费
        result.setOfficialAccountOrderRoiAll(result.getCostTotal() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountTotal(), result.getCostTotal()));

        // 上一次聚合的 5分钟数据
        if (lastMinuteDWD != null && lastMinuteDWD.getHour().equals(result.getHour())) {
            result.setCostMinute(result.getCostHour() - lastMinuteDWD.getCostHour());
            result.setCompensationAmountMinute(result.getCompensationAmountHour() - lastMinuteDWD.getCompensationAmountHour());
            result.setViewCountMinute(result.getViewCountHour() - lastMinuteDWD.getViewCountHour());
            result.setValidClickCountMinute(result.getValidClickCountHour() - lastMinuteDWD.getValidClickCountHour());
            result.setValuableClickCountMinute(result.getValuableClickCountHour() - lastMinuteDWD.getValuableClickCountHour());
            result.setConversionsCountMinute(result.getConversionsCountHour() - lastMinuteDWD.getConversionsCountHour());
            result.setDeepConversionsCountMinute(result.getDeepConversionsCountHour() - lastMinuteDWD.getDeepConversionsCountHour());
            result.setOrderCountMinute(result.getOrderCountHour() - lastMinuteDWD.getOrderCountHour());
            result.setFirstDayOrderCountMinute(result.getFirstDayOrderCountHour() - lastMinuteDWD.getFirstDayOrderCountHour());
            result.setOrderAmountMinute(result.getOrderAmountHour() - lastMinuteDWD.getOrderAmountHour());
            result.setFirstDayOrderAmountMinute(result.getFirstDayOrderAmountHour() - lastMinuteDWD.getFirstDayOrderAmountHour());
            result.setSignInCountMinute(result.getSignInCountHour() - lastMinuteDWD.getSignInCountHour());
            result.setScanFollowCountMinute(result.getScanFollowCountHour() - lastMinuteDWD.getScanFollowCountHour());
            result.setWechatAppRegisterUvMinute(result.getWechatAppRegisterUvHour() - lastMinuteDWD.getWechatAppRegisterUvHour());
            result.setWechatMinigameRetentionCountMinute(result.getWechatMinigameRetentionCountHour() - lastMinuteDWD.getWechatMinigameRetentionCountHour());
            result.setWechatMinigameCheckoutCountMinute(result.getWechatMinigameCheckoutCountHour() - lastMinuteDWD.getWechatMinigameCheckoutCountHour());
            result.setWechatMinigameCheckoutAmountMinute(result.getWechatMinigameCheckoutAmountHour() - lastMinuteDWD.getWechatMinigameCheckoutAmountHour());
            result.setOfficialAccountFollowCountMinute(result.getOfficialAccountFollowCountHour() - lastMinuteDWD.getOfficialAccountFollowCountHour());
            result.setOfficialAccountRegisterUserCountMinute(result.getOfficialAccountRegisterUserCountHour() - lastMinuteDWD.getOfficialAccountRegisterUserCountHour());
            result.setOfficialAccountRegisterAmountMinute(result.getOfficialAccountRegisterAmountHour() - lastMinuteDWD.getOfficialAccountRegisterAmountHour());
            result.setOfficialAccountApplyCountMinute(result.getOfficialAccountApplyCountHour() - lastMinuteDWD.getOfficialAccountApplyCountHour());
            result.setOfficialAccountApplyUserCountMinute(result.getOfficialAccountApplyUserCountHour() - lastMinuteDWD.getOfficialAccountApplyUserCountHour());
            result.setOfficialAccountApplyAmountMinute(result.getOfficialAccountApplyAmountHour() - lastMinuteDWD.getOfficialAccountApplyAmountHour());
            result.setOfficialAccountOrderCountMinute(result.getOfficialAccountOrderCountHour() - lastMinuteDWD.getOfficialAccountOrderCountHour());
            result.setOfficialAccountFirstDayOrderCountMinute(result.getOfficialAccountFirstDayOrderCountHour() - lastMinuteDWD.getOfficialAccountFirstDayOrderCountHour());
            result.setOfficialAccountOrderUserCountMinute(result.getOfficialAccountOrderUserCountHour() - lastMinuteDWD.getOfficialAccountOrderUserCountHour());
            result.setOfficialAccountOrderAmountMinute(result.getOfficialAccountOrderAmountHour() - lastMinuteDWD.getOfficialAccountOrderAmountHour());
            result.setOfficialAccountFirstDayOrderAmountMinute(result.getOfficialAccountFirstDayOrderAmountHour() - lastMinuteDWD.getOfficialAccountFirstDayOrderAmountHour());
            result.setOfficialAccountConsultCountMinute(result.getOfficialAccountConsultCountHour() - lastMinuteDWD.getOfficialAccountConsultCountHour());
            result.setOfficialAccountReaderCountMinute(result.getOfficialAccountReaderCountHour() - lastMinuteDWD.getOfficialAccountReaderCountHour());
            result.setOfficialAccountCreditApplyUserCountMinute(result.getOfficialAccountCreditApplyUserCountHour() - lastMinuteDWD.getOfficialAccountCreditApplyUserCountHour());
            result.setOfficialAccountCreditUserCountMinute(result.getOfficialAccountCreditUserCountHour() - lastMinuteDWD.getOfficialAccountCreditUserCountHour());
            result.setForwardCountMinute(result.getForwardCountHour() - lastMinuteDWD.getForwardCountHour());
            result.setForwardUserCountMinute(result.getForwardUserCountHour() - lastMinuteDWD.getForwardUserCountHour());
            result.setNoInterestCountMinute(result.getNoInterestCountHour() - lastMinuteDWD.getNoInterestCountHour());


            // 消耗 / 曝光
            result.setThousandDisplayPriceMinute(result.getViewCountMinute() == 0 ? 0 : NumberUtil.divideForAd(result.getCostMinute(), result.getViewCountMinute()).multiply(new BigDecimal(1000)).longValue());
            // 广告点击次数 / 广告曝光次数
            result.setCtrMinute(result.getViewCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValidClickCountMinute(), result.getViewCountMinute()));
            // 广告花费/广告点击次数
            result.setCpcMinute(result.getValidClickCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getValidClickCountMinute()));
            // 广告可转化点击次数/广告曝光次数
            result.setValuableClickRateMinute(result.getViewCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getValuableClickCountMinute(), result.getViewCountMinute()));
            // 广告花费/可转化点击次数
            result.setValuableClickCostMinute(result.getValuableClickCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getValuableClickCountMinute()));
            // 广告花费/转化目标量
            result.setConversionsCostMinute(result.getConversionsCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getConversionsCountMinute()));
            // 公众号：转化目标量/点击次数。
            result.setConversionsRateMinute(result.getValidClickCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getConversionsCountMinute(), result.getValidClickCountMinute()));
            // 广告花费/深度转化目标量
            result.setDeepConversionsCostMinute(result.getDeepConversionsCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getDeepConversionsCountMinute()));
            // 深度转化目标量/可转化点击次数
            result.setDeepConversionsRateMinute(result.getValuableClickCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getDeepConversionsCountMinute(), result.getValuableClickCountMinute()));
            // 广告花费/下单量
            result.setWebOrderCostMinute(result.getOrderCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getOrderCountMinute()));
            // 下单量/点击次数
            result.setOrderRateMinute(result.getValidClickCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderCountMinute(), result.getValidClickCountMinute()));
            // 下单金额/下单量
            result.setOrderUnitPriceMinute(result.getOrderCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getOrderAmountMinute(), result.getOrderCountMinute()));
            // 下单金额/广告花费
            result.setOrderRoiMinute(result.getCostMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountMinute(), result.getCostMinute()));
            // 广告消耗 / 小游戏注册人数
            result.setWechatMinigameRegisterCostMinute(result.getWechatAppRegisterUvMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getWechatAppRegisterUvMinute()));
            // 小游戏注册人数 / 广告点击次数
            result.setWechatMinigameRegisterRateMinute(result.getValidClickCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getWechatAppRegisterUvMinute(), result.getValidClickCountMinute()));
            // 总收益 / 总人数
            result.setWechatMinigameArpuMinute(result.getWechatAppRegisterUvMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOrderAmountMinute(), result.getWechatAppRegisterUvMinute()));
            // 关注次数 / 点击次数
            result.setOfficialAccountFollowRateMinute(result.getValidClickCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountFollowCountMinute(), result.getValidClickCountMinute()));
            // 公众号内注册人数 / 公众号关注次数
            result.setOfficialAccountRegisterRateMinute(result.getOfficialAccountFollowCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountRegisterUserCountMinute(), result.getOfficialAccountFollowCountMinute()));
            // 广告消耗 / 广告注册人数
            result.setOfficialAccountRegisterCostMinute(result.getOfficialAccountRegisterUserCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getOfficialAccountRegisterUserCountMinute()));
            // 注册产生的订单金额累计/广告花费
            result.setOfficialAccountRegisterRoiMinute(result.getCostMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountRegisterAmountMinute(), result.getCostMinute()));
            // 公众号内填单的独立用户数/公众号关注次数
            result.setOfficialAccountApplyRateMinute(result.getOfficialAccountFollowCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountApplyUserCountMinute(), result.getOfficialAccountFollowCountMinute()));
            // 广告花费/广告产生的填单行为数量
            result.setOfficialAccountApplyCostMinute(result.getOfficialAccountApplyUserCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getOfficialAccountApplyUserCountMinute()));
            // 填单产生的订单金额累计/广告花费
            result.setOfficialAccountApplyRoiMinute(result.getCostMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountApplyAmountMinute(), result.getCostMinute()));
            // 公众号内下单独立用户数（UV）/公众号关注次数
            result.setOfficialAccountOrderRateMinute(result.getOfficialAccountFollowCountMinute() == 0 ? BigDecimal.ZERO : NumberUtil.divideForAd(result.getOfficialAccountOrderUserCountMinute(), result.getOfficialAccountFollowCountMinute()));
            // 广告花费/广告产生的下单行为数量
            result.setOfficialAccountOrderCostMinute(result.getOfficialAccountOrderCountMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getCostMinute(), result.getOfficialAccountOrderCountMinute()));
            // 下单产生的订单金额累计/广告花费
            result.setOfficialAccountOrderRoiMinute(result.getCostMinute() == 0 ? 0 : NumberUtil.divideForMoney(result.getOfficialAccountOrderAmountMinute(), result.getCostMinute()));
        } else {
            result.setCostDeviationRateMinute(statODS.getCostDeviationRate());
            result.setCostMinute(statODS.getCost());
            result.setCompensationAmountMinute(statODS.getCompensationAmount());
            result.setViewCountMinute(statODS.getViewCount());
            result.setThousandDisplayPriceMinute(statODS.getThousandDisplayPrice());
            result.setAvgViewPerUserMinute(statODS.getAvgViewPerUser());
            result.setValidClickCountMinute(statODS.getValidClickCount());
            result.setCtrMinute(statODS.getCtr());
            result.setCpcMinute(statODS.getCpc());
            result.setValuableClickCountMinute(statODS.getValuableClickCount());
            result.setValuableClickRateMinute(statODS.getValuableClickRate());
            result.setValuableClickCostMinute(statODS.getValuableClickCost());
            result.setConversionsCountMinute(statODS.getConversionsCount());
            result.setConversionsCostMinute(statODS.getConversionsCost());
            result.setConversionsRateMinute(statODS.getConversionsRate());
            result.setDeepConversionsCountMinute(statODS.getDeepConversionsCount());
            result.setDeepConversionsCostMinute(statODS.getDeepConversionsCost());
            result.setDeepConversionsRateMinute(statODS.getDeepConversionsRate());
            result.setOrderCountMinute(statODS.getOrderCount());
            result.setFirstDayOrderCountMinute(statODS.getFirstDayOrderCount());
            result.setWebOrderCostMinute(statODS.getWebOrderCost());
            result.setOrderRateMinute(statODS.getOrderRate());
            result.setOrderAmountMinute(statODS.getOrderAmount());
            result.setFirstDayOrderAmountMinute(statODS.getFirstDayOrderAmount());
            result.setOrderUnitPriceMinute(statODS.getOrderUnitPrice());
            result.setOrderRoiMinute(statODS.getOrderRoi());
            result.setSignInCountMinute(statODS.getSignInCount());
            result.setScanFollowCountMinute(statODS.getScanFollowCount());
            result.setWechatAppRegisterUvMinute(statODS.getWechatAppRegisterUv());
            result.setWechatMinigameRegisterCostMinute(statODS.getWechatMinigameRegisterCost());
            result.setWechatMinigameRegisterRateMinute(statODS.getWechatMinigameRegisterRate());
            result.setWechatMinigameArpuMinute(statODS.getWechatMinigameArpu());
            result.setWechatMinigameRetentionCountMinute(statODS.getWechatMinigameRetentionCount());
            result.setWechatMinigameCheckoutCountMinute(statODS.getWechatMinigameCheckoutCount());
            result.setWechatMinigameCheckoutAmountMinute(statODS.getWechatMinigameCheckoutAmount());
            result.setOfficialAccountFollowCountMinute(statODS.getOfficialAccountFollowCount());
            result.setOfficialAccountFollowRateMinute(statODS.getOfficialAccountFollowRate());
            result.setOfficialAccountRegisterUserCountMinute(statODS.getOfficialAccountRegisterUserCount());
            result.setOfficialAccountRegisterRateMinute(statODS.getOfficialAccountRegisterRate());
            result.setOfficialAccountRegisterCostMinute(statODS.getOfficialAccountRegisterCost());
            result.setOfficialAccountRegisterAmountMinute(statODS.getOfficialAccountRegisterAmount());
            result.setOfficialAccountRegisterRoiMinute(statODS.getOfficialAccountRegisterRoi());
            result.setOfficialAccountApplyCountMinute(statODS.getOfficialAccountApplyCount());
            result.setOfficialAccountApplyUserCountMinute(statODS.getOfficialAccountApplyUserCount());
            result.setOfficialAccountApplyRateMinute(statODS.getOfficialAccountApplyRate());
            result.setOfficialAccountApplyCostMinute(statODS.getOfficialAccountApplyCost());
            result.setOfficialAccountApplyAmountMinute(statODS.getOfficialAccountApplyAmount());
            result.setOfficialAccountApplyRoiMinute(statODS.getOfficialAccountApplyRoi());
            result.setOfficialAccountOrderCountMinute(statODS.getOfficialAccountOrderCount());
            result.setOfficialAccountFirstDayOrderCountMinute(statODS.getOfficialAccountFirstDayOrderCount());
            result.setOfficialAccountOrderUserCountMinute(statODS.getOfficialAccountOrderUserCount());
            result.setOfficialAccountOrderRateMinute(statODS.getOfficialAccountOrderRate());
            result.setOfficialAccountOrderCostMinute(statODS.getOfficialAccountOrderCost());
            result.setOfficialAccountOrderAmountMinute(statODS.getOfficialAccountOrderAmount());
            result.setOfficialAccountFirstDayOrderAmountMinute(statODS.getOfficialAccountFirstDayOrderAmount());
            result.setOfficialAccountOrderRoiMinute(statODS.getOfficialAccountOrderRoi());
            result.setOfficialAccountConsultCountMinute(statODS.getOfficialAccountConsultCount());
            result.setOfficialAccountReaderCountMinute(statODS.getOfficialAccountReaderCount());
            result.setOfficialAccountCreditApplyUserCountMinute(statODS.getOfficialAccountCreditApplyUserCount());
            result.setOfficialAccountCreditUserCountMinute(statODS.getOfficialAccountCreditUserCount());
            result.setForwardCountMinute(statODS.getForwardCount());
            result.setForwardUserCountMinute(statODS.getForwardUserCount());
            result.setNoInterestCountMinute(statODS.getNoInterestCount());
        }
        result.setAdGroupMapStr(PlanUtil.adGroupMapStr(adGroupMap));
        result.setAdIdsStr(PlanUtil.adIdsStr(statODS.getAdId()));
        return result;
    }

    private static PlanStatOfMinuteDWD initValue(PlanStatOfMinuteDWD dwd) {
        dwd.setCostDeviationRateTotal(BigDecimal.ZERO);
        dwd.setCostDeviationRateDay(BigDecimal.ZERO);
        dwd.setCostDeviationRateHour(BigDecimal.ZERO);
        dwd.setCostDeviationRateMinute(BigDecimal.ZERO);
        dwd.setCostTotal(0L);
        dwd.setCostDay(0L);
        dwd.setCostHour(0L);
        dwd.setCostMinute(0L);
        dwd.setCompensationAmountTotal(0L);
        dwd.setCompensationAmountDay(0L);
        dwd.setCompensationAmountHour(0L);
        dwd.setCompensationAmountMinute(0L);
        dwd.setViewCountTotal(0L);
        dwd.setViewCountDay(0L);
        dwd.setViewCountHour(0L);
        dwd.setViewCountMinute(0L);
        dwd.setThousandDisplayPriceAll(0L);
        dwd.setThousandDisplayPriceDay(0L);
        dwd.setThousandDisplayPriceHour(0L);
        dwd.setThousandDisplayPriceMinute(0L);
        dwd.setAvgViewPerUserAll(BigDecimal.ZERO);
        dwd.setAvgViewPerUserDay(BigDecimal.ZERO);
        dwd.setAvgViewPerUserHour(BigDecimal.ZERO);
        dwd.setAvgViewPerUserMinute(BigDecimal.ZERO);
        dwd.setValidClickCountTotal(0L);
        dwd.setValidClickCountDay(0L);
        dwd.setValidClickCountHour(0L);
        dwd.setValidClickCountMinute(0L);
        dwd.setCtrAll(BigDecimal.ZERO);
        dwd.setCtrDay(BigDecimal.ZERO);
        dwd.setCtrHour(BigDecimal.ZERO);
        dwd.setCtrMinute(BigDecimal.ZERO);
        dwd.setCpcAll(0L);
        dwd.setCpcDay(0L);
        dwd.setCpcHour(0L);
        dwd.setCpcMinute(0L);
        dwd.setValuableClickCountTotal(0L);
        dwd.setValuableClickCountDay(0L);
        dwd.setValuableClickCountHour(0L);
        dwd.setValuableClickCountMinute(0L);
        dwd.setValuableClickRateAll(BigDecimal.ZERO);
        dwd.setValuableClickRateDay(BigDecimal.ZERO);
        dwd.setValuableClickRateHour(BigDecimal.ZERO);
        dwd.setValuableClickRateMinute(BigDecimal.ZERO);
        dwd.setValuableClickCostAll(0L);
        dwd.setValuableClickCostDay(0L);
        dwd.setValuableClickCostHour(0L);
        dwd.setValuableClickCostMinute(0L);
        dwd.setConversionsCountTotal(0L);
        dwd.setConversionsCountDay(0L);
        dwd.setConversionsCountHour(0L);
        dwd.setConversionsCountMinute(0L);
        dwd.setConversionsCostAll(0L);
        dwd.setConversionsCostDay(0L);
        dwd.setConversionsCostHour(0L);
        dwd.setConversionsCostMinute(0L);
        dwd.setConversionsRateAll(BigDecimal.ZERO);
        dwd.setConversionsRateDay(BigDecimal.ZERO);
        dwd.setConversionsRateHour(BigDecimal.ZERO);
        dwd.setConversionsRateMinute(BigDecimal.ZERO);
        dwd.setDeepConversionsCountTotal(0L);
        dwd.setDeepConversionsCountDay(0L);
        dwd.setDeepConversionsCountHour(0L);
        dwd.setDeepConversionsCountMinute(0L);
        dwd.setDeepConversionsCostAll(0L);
        dwd.setDeepConversionsCostDay(0L);
        dwd.setDeepConversionsCostHour(0L);
        dwd.setDeepConversionsCostMinute(0L);
        dwd.setDeepConversionsRateAll(BigDecimal.ZERO);
        dwd.setDeepConversionsRateDay(BigDecimal.ZERO);
        dwd.setDeepConversionsRateHour(BigDecimal.ZERO);
        dwd.setDeepConversionsRateMinute(BigDecimal.ZERO);
        dwd.setOrderCountTotal(0L);
        dwd.setOrderCountDay(0L);
        dwd.setOrderCountHour(0L);
        dwd.setOrderCountMinute(0L);
        dwd.setFirstDayOrderCountTotal(0L);
        dwd.setFirstDayOrderCountDay(0L);
        dwd.setFirstDayOrderCountHour(0L);
        dwd.setFirstDayOrderCountMinute(0L);
        dwd.setWebOrderCostAll(0L);
        dwd.setWebOrderCostDay(0L);
        dwd.setWebOrderCostHour(0L);
        dwd.setWebOrderCostMinute(0L);
        dwd.setOrderRateAll(BigDecimal.ZERO);
        dwd.setOrderRateDay(BigDecimal.ZERO);
        dwd.setOrderRateHour(BigDecimal.ZERO);
        dwd.setOrderRateMinute(BigDecimal.ZERO);
        dwd.setOrderAmountTotal(0L);
        dwd.setOrderAmountDay(0L);
        dwd.setOrderAmountHour(0L);
        dwd.setOrderAmountMinute(0L);
        dwd.setFirstDayOrderAmountTotal(0L);
        dwd.setFirstDayOrderAmountDay(0L);
        dwd.setFirstDayOrderAmountHour(0L);
        dwd.setFirstDayOrderAmountMinute(0L);
        dwd.setOrderUnitPriceAll(0L);
        dwd.setOrderUnitPriceDay(0L);
        dwd.setOrderUnitPriceHour(0L);
        dwd.setOrderUnitPriceMinute(0L);
        dwd.setOrderRoiAll(BigDecimal.ZERO);
        dwd.setOrderRoiDay(BigDecimal.ZERO);
        dwd.setOrderRoiHour(BigDecimal.ZERO);
        dwd.setOrderRoiMinute(BigDecimal.ZERO);
        dwd.setSignInCountTotal(0L);
        dwd.setSignInCountDay(0L);
        dwd.setSignInCountHour(0L);
        dwd.setSignInCountMinute(0L);
        dwd.setScanFollowCountTotal(0L);
        dwd.setScanFollowCountDay(0L);
        dwd.setScanFollowCountHour(0L);
        dwd.setScanFollowCountMinute(0L);
        dwd.setWechatAppRegisterUvTotal(0L);
        dwd.setWechatAppRegisterUvDay(0L);
        dwd.setWechatAppRegisterUvHour(0L);
        dwd.setWechatAppRegisterUvMinute(0L);
        dwd.setWechatMinigameRegisterCostAll(0L);
        dwd.setWechatMinigameRegisterCostDay(0L);
        dwd.setWechatMinigameRegisterCostHour(0L);
        dwd.setWechatMinigameRegisterCostMinute(0L);
        dwd.setWechatMinigameRegisterRateAll(BigDecimal.ZERO);
        dwd.setWechatMinigameRegisterRateDay(BigDecimal.ZERO);
        dwd.setWechatMinigameRegisterRateHour(BigDecimal.ZERO);
        dwd.setWechatMinigameRegisterRateMinute(BigDecimal.ZERO);
        dwd.setWechatMinigameArpuAll(BigDecimal.ZERO);
        dwd.setWechatMinigameArpuDay(BigDecimal.ZERO);
        dwd.setWechatMinigameArpuHour(BigDecimal.ZERO);
        dwd.setWechatMinigameArpuMinute(BigDecimal.ZERO);
        dwd.setWechatMinigameRetentionCountTotal(0L);
        dwd.setWechatMinigameRetentionCountDay(0L);
        dwd.setWechatMinigameRetentionCountHour(0L);
        dwd.setWechatMinigameRetentionCountMinute(0L);
        dwd.setWechatMinigameCheckoutCountTotal(0L);
        dwd.setWechatMinigameCheckoutCountDay(0L);
        dwd.setWechatMinigameCheckoutCountHour(0L);
        dwd.setWechatMinigameCheckoutCountMinute(0L);
        dwd.setWechatMinigameCheckoutAmountTotal(0L);
        dwd.setWechatMinigameCheckoutAmountDay(0L);
        dwd.setWechatMinigameCheckoutAmountHour(0L);
        dwd.setWechatMinigameCheckoutAmountMinute(0L);
        dwd.setOfficialAccountFollowCountTotal(0L);
        dwd.setOfficialAccountFollowCountDay(0L);
        dwd.setOfficialAccountFollowCountHour(0L);
        dwd.setOfficialAccountFollowCountMinute(0L);
        dwd.setOfficialAccountFollowRateAll(BigDecimal.ZERO);
        dwd.setOfficialAccountFollowRateDay(BigDecimal.ZERO);
        dwd.setOfficialAccountFollowRateHour(BigDecimal.ZERO);
        dwd.setOfficialAccountFollowRateMinute(BigDecimal.ZERO);
        dwd.setOfficialAccountRegisterUserCountTotal(0L);
        dwd.setOfficialAccountRegisterUserCountDay(0L);
        dwd.setOfficialAccountRegisterUserCountHour(0L);
        dwd.setOfficialAccountRegisterUserCountMinute(0L);
        dwd.setOfficialAccountRegisterRateAll(BigDecimal.ZERO);
        dwd.setOfficialAccountRegisterRateDay(BigDecimal.ZERO);
        dwd.setOfficialAccountRegisterRateHour(BigDecimal.ZERO);
        dwd.setOfficialAccountRegisterRateMinute(BigDecimal.ZERO);
        dwd.setOfficialAccountRegisterCostAll(0L);
        dwd.setOfficialAccountRegisterCostDay(0L);
        dwd.setOfficialAccountRegisterCostHour(0L);
        dwd.setOfficialAccountRegisterCostMinute(0L);
        dwd.setOfficialAccountRegisterAmountTotal(0L);
        dwd.setOfficialAccountRegisterAmountDay(0L);
        dwd.setOfficialAccountRegisterAmountHour(0L);
        dwd.setOfficialAccountRegisterAmountMinute(0L);
        dwd.setOfficialAccountRegisterRoiAll(0L);
        dwd.setOfficialAccountRegisterRoiDay(0L);
        dwd.setOfficialAccountRegisterRoiHour(0L);
        dwd.setOfficialAccountRegisterRoiMinute(0L);
        dwd.setOfficialAccountApplyCountTotal(0L);
        dwd.setOfficialAccountApplyCountDay(0L);
        dwd.setOfficialAccountApplyCountHour(0L);
        dwd.setOfficialAccountApplyCountMinute(0L);
        dwd.setOfficialAccountApplyUserCountTotal(0L);
        dwd.setOfficialAccountApplyUserCountDay(0L);
        dwd.setOfficialAccountApplyUserCountHour(0L);
        dwd.setOfficialAccountApplyUserCountMinute(0L);
        dwd.setOfficialAccountApplyRateAll(BigDecimal.ZERO);
        dwd.setOfficialAccountApplyRateDay(BigDecimal.ZERO);
        dwd.setOfficialAccountApplyRateHour(BigDecimal.ZERO);
        dwd.setOfficialAccountApplyRateMinute(BigDecimal.ZERO);
        dwd.setOfficialAccountApplyCostAll(0L);
        dwd.setOfficialAccountApplyCostDay(0L);
        dwd.setOfficialAccountApplyCostHour(0L);
        dwd.setOfficialAccountApplyCostMinute(0L);
        dwd.setOfficialAccountApplyAmountTotal(0L);
        dwd.setOfficialAccountApplyAmountDay(0L);
        dwd.setOfficialAccountApplyAmountHour(0L);
        dwd.setOfficialAccountApplyAmountMinute(0L);
        dwd.setOfficialAccountApplyRoiAll(0L);
        dwd.setOfficialAccountApplyRoiDay(0L);
        dwd.setOfficialAccountApplyRoiHour(0L);
        dwd.setOfficialAccountApplyRoiMinute(0L);
        dwd.setOfficialAccountOrderCountTotal(0L);
        dwd.setOfficialAccountOrderCountDay(0L);
        dwd.setOfficialAccountOrderCountHour(0L);
        dwd.setOfficialAccountOrderCountMinute(0L);
        dwd.setOfficialAccountFirstDayOrderCountTotal(0L);
        dwd.setOfficialAccountFirstDayOrderCountDay(0L);
        dwd.setOfficialAccountFirstDayOrderCountHour(0L);
        dwd.setOfficialAccountFirstDayOrderCountMinute(0L);
        dwd.setOfficialAccountOrderUserCountTotal(0L);
        dwd.setOfficialAccountOrderUserCountDay(0L);
        dwd.setOfficialAccountOrderUserCountHour(0L);
        dwd.setOfficialAccountOrderUserCountMinute(0L);
        dwd.setOfficialAccountOrderRateAll(BigDecimal.ZERO);
        dwd.setOfficialAccountOrderRateDay(BigDecimal.ZERO);
        dwd.setOfficialAccountOrderRateHour(BigDecimal.ZERO);
        dwd.setOfficialAccountOrderRateMinute(BigDecimal.ZERO);
        dwd.setOfficialAccountOrderCostAll(0L);
        dwd.setOfficialAccountOrderCostDay(0L);
        dwd.setOfficialAccountOrderCostHour(0L);
        dwd.setOfficialAccountOrderCostMinute(0L);
        dwd.setOfficialAccountOrderAmountTotal(0L);
        dwd.setOfficialAccountOrderAmountDay(0L);
        dwd.setOfficialAccountOrderAmountHour(0L);
        dwd.setOfficialAccountOrderAmountMinute(0L);
        dwd.setOfficialAccountFirstDayOrderAmountTotal(0L);
        dwd.setOfficialAccountFirstDayOrderAmountDay(0L);
        dwd.setOfficialAccountFirstDayOrderAmountHour(0L);
        dwd.setOfficialAccountFirstDayOrderAmountMinute(0L);
        dwd.setOfficialAccountOrderRoiAll(0L);
        dwd.setOfficialAccountOrderRoiDay(0L);
        dwd.setOfficialAccountOrderRoiHour(0L);
        dwd.setOfficialAccountOrderRoiMinute(0L);
        dwd.setOfficialAccountConsultCountTotal(0L);
        dwd.setOfficialAccountConsultCountDay(0L);
        dwd.setOfficialAccountConsultCountHour(0L);
        dwd.setOfficialAccountConsultCountMinute(0L);
        dwd.setOfficialAccountReaderCountTotal(0L);
        dwd.setOfficialAccountReaderCountDay(0L);
        dwd.setOfficialAccountReaderCountHour(0L);
        dwd.setOfficialAccountReaderCountMinute(0L);
        dwd.setOfficialAccountCreditApplyUserCountTotal(0L);
        dwd.setOfficialAccountCreditApplyUserCountDay(0L);
        dwd.setOfficialAccountCreditApplyUserCountHour(0L);
        dwd.setOfficialAccountCreditApplyUserCountMinute(0L);
        dwd.setOfficialAccountCreditUserCountTotal(0L);
        dwd.setOfficialAccountCreditUserCountDay(0L);
        dwd.setOfficialAccountCreditUserCountHour(0L);
        dwd.setOfficialAccountCreditUserCountMinute(0L);
        dwd.setForwardCountTotal(0L);
        dwd.setForwardCountDay(0L);
        dwd.setForwardCountHour(0L);
        dwd.setForwardCountMinute(0L);
        dwd.setForwardUserCountTotal(0L);
        dwd.setForwardUserCountDay(0L);
        dwd.setForwardUserCountHour(0L);
        dwd.setForwardUserCountMinute(0L);
        dwd.setNoInterestCountTotal(0L);
        dwd.setNoInterestCountDay(0L);
        dwd.setNoInterestCountHour(0L);
        dwd.setNoInterestCountMinute(0L);
        return dwd;
    }
}
