package flink.zanxiangnet.ad.monitoring.process;

import com.tencent.ads.model.HourlyReportsGetListStruct;
import flink.zanxiangnet.ad.monitoring.pojo.dto.AdDataOfMinuteDTO;
import flink.zanxiangnet.ad.monitoring.pojo.entity.AdDataOfHourODS;
import flink.zanxiangnet.ad.monitoring.pojo.entity.AdDataOfMinuteODS;
import flink.zanxiangnet.ad.monitoring.util.DateUtil;
import flink.zanxiangnet.ad.monitoring.util.JsonUtil;
import org.apache.flink.streaming.api.functions.ProcessFunction;
import org.apache.flink.util.Collector;
import org.apache.flink.util.OutputTag;
import org.springframework.beans.BeanUtils;

import java.time.LocalDateTime;
import java.util.Date;

/**
 * 对小时数据分流
 */
public class AdHourDTOStreamProcess extends ProcessFunction<String, AdDataOfMinuteODS> {
    final OutputTag<AdDataOfMinuteODS> adMinuteStreamTag;
    final OutputTag<AdDataOfHourODS> adHourStreamTag;

    public AdHourDTOStreamProcess(OutputTag<AdDataOfMinuteODS> adMinuteStreamTag, OutputTag<AdDataOfHourODS> adHourStreamTag) {
        this.adMinuteStreamTag = adMinuteStreamTag;
        this.adHourStreamTag = adHourStreamTag;
    }

    @Override
    public void processElement(String adDataStr, ProcessFunction<String, AdDataOfMinuteODS>.Context context, Collector<AdDataOfMinuteODS> collector) throws Exception {
        AdDataOfMinuteDTO dto = JsonUtil.toObj(adDataStr, AdDataOfMinuteDTO.class);
        // 指记录被创建的时间
        long createTime = dto.getCreateTime();
        // 指记录统计的时间（如果是实时统计的数据精确到分钟，回滚的历史数据精确到天）
        LocalDateTime statDateTime = DateUtil.milliToLocalDateTime(dto.getDataTime()).withSecond(0).withNano(0);
        long statTime = DateUtil.localDateTimeToMilli(statDateTime);
        HourlyReportsGetListStruct struct = dto.getHourlyReportsGetListStruct();

        if (createTime - statTime > (60 * 60 * 1000L)) {
            AdDataOfHourODS adODS = new AdDataOfHourODS();
            BeanUtils.copyProperties(struct, adODS);
            adODS.setStatDay(DateUtil.formatLocalDate(DateUtil.milliToLocalDate(statTime)));
            adODS.setHour(dto.getHourlyReportsGetListStruct().getHour().intValue());
            adODS.setStatTime(DateUtil.localDateTimeToMilli(DateUtil.milliToLocalDateTime(statTime).withMinute(0)));
            adODS.setAccountId(dto.getAccountId());
            adODS.setAgencyAccountId(dto.getHourlyReportsGetListStruct().getAccountId());
            adODS.setCreateTime(new Date(createTime));
            adODS.removeNull();
            context.output(adHourStreamTag, adODS);
        } else {
            AdDataOfMinuteODS adODS = new AdDataOfMinuteODS();
            BeanUtils.copyProperties(struct, adODS);
            adODS.setStatDay(DateUtil.formatLocalDate(DateUtil.milliToLocalDate(statTime)));
            adODS.setHour(dto.getHourlyReportsGetListStruct().getHour().intValue());
            adODS.setStatTime(statTime);
            adODS.setAccountId(dto.getAccountId());
            adODS.setAgencyAccountId(dto.getHourlyReportsGetListStruct().getAccountId());
            adODS.setCreateTime(new Date(createTime));
            adODS.removeNull();
            context.output(adMinuteStreamTag, adODS);
        }
    }
}
