package flink.zanxiangnet.ad.monitoring.process;

import flink.zanxiangnet.ad.monitoring.pojo.entity.AdStatOfHourDWD;
import flink.zanxiangnet.ad.monitoring.pojo.entity.CostHourDM;
import flink.zanxiangnet.ad.monitoring.util.DateUtil;
import org.apache.flink.api.common.state.MapState;
import org.apache.flink.api.common.state.MapStateDescriptor;
import org.apache.flink.api.common.typeinfo.Types;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.KeyedProcessFunction;
import org.apache.flink.util.Collector;

import java.io.IOException;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.util.*;

public class CostHourProcess extends KeyedProcessFunction<Long, AdStatOfHourDWD, CostHourDM> {

    private MapState<String, Map<Integer, AdStatOfHourDWD>> historyReduceState;


    @Override
    public void open(Configuration conf) throws SQLException, ClassNotFoundException, IOException {
        historyReduceState = getRuntimeContext().getMapState(new MapStateDescriptor<>("historyReduceState", Types.STRING, Types.MAP(Types.INT, Types.POJO(AdStatOfHourDWD.class))));
    }

    @Override
    public void processElement(AdStatOfHourDWD adStatOfHourDWD, KeyedProcessFunction<Long, AdStatOfHourDWD, CostHourDM>.Context context,
                               Collector<CostHourDM> collector) throws Exception {
        LocalDate day = DateUtil.parseLocalDate(adStatOfHourDWD.getStatDay());
        Integer hour = adStatOfHourDWD.getHour();

        LocalDate lastHourDay = day, lastTwoHourDay = day, lastThreeHourDay = day;
        int lastHour = hour - 1, lastTwoHour = hour - 2, lastThreeHour = hour - 3;
        if (hour == 0) {
            lastHourDay = day.minusDays(1L);
            lastHour = 23;
            lastTwoHourDay = day.minusDays(1L);
            lastTwoHour = 22;
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 21;
        } else if (hour == 1) {
            lastTwoHourDay = day.minusDays(1L);
            lastTwoHour = 23;
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 22;
        } else if (hour == 2) {
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 23;
        }
        long costDiff = adStatOfHourDWD.getCostHour(), costLastHour = 0L;
        Map<Integer, AdStatOfHourDWD> lastHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastHourDay));
        if (lastHourMapping != null && !lastHourMapping.isEmpty()) {
            AdStatOfHourDWD lastHourDWD = lastHourMapping.get(lastHour);
            if (lastHourDWD != null) {
                costLastHour = lastHourDWD.getCostHour();
                costDiff = adStatOfHourDWD.getCostHour() - lastHourDWD.getCostHour();
            }
        }
        long costLastHourDiff = costLastHour, costLastTwoHour = 0L;
        Map<Integer, AdStatOfHourDWD> lastTwoHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastTwoHourDay));
        if (lastTwoHourMapping != null && !lastTwoHourMapping.isEmpty()) {
            AdStatOfHourDWD lastTwoHourDWD = lastTwoHourMapping.get(lastTwoHour);
            if (lastTwoHourDWD != null) {
                costLastTwoHour = lastTwoHourDWD.getCostHour();
                costLastHourDiff = costLastHour - lastTwoHourDWD.getCostHour();
            }
        }
        long costLastTwoHourDiff = costLastTwoHour, costLastThreeHour = 0;
        Map<Integer, AdStatOfHourDWD> lastThreeHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastThreeHourDay));
        if (lastThreeHourMapping != null && !lastThreeHourMapping.isEmpty()) {
            AdStatOfHourDWD lastThreeHourDWD = lastThreeHourMapping.get(lastThreeHour);
            if (lastThreeHourDWD != null) {
                costLastThreeHour = lastThreeHourDWD.getCostHour();
                costLastTwoHourDiff = costLastTwoHour - lastThreeHourDWD.getCostHour();
            }
        }
        long costLastThreeTrend = costLastHourDiff > 0 && costDiff > 0 ? 1 : 0;

        if (historyReduceState.get(adStatOfHourDWD.getStatDay()) == null) {
            Map<Integer, AdStatOfHourDWD> hourMapping = new HashMap<>(24);
            hourMapping.put(adStatOfHourDWD.getHour(), adStatOfHourDWD);
            historyReduceState.put(adStatOfHourDWD.getStatDay(), hourMapping);
        } else {
            Map<Integer, AdStatOfHourDWD> hourMapping = historyReduceState.get(adStatOfHourDWD.getStatDay());
            hourMapping.put(adStatOfHourDWD.getHour(), adStatOfHourDWD);
            historyReduceState.put(adStatOfHourDWD.getStatDay(), hourMapping);
        }

        CostHourDM costHourDM = dataChange(adStatOfHourDWD);
        costHourDM.setCostDiff(costDiff);
        costHourDM.setCostLastHour(costLastHour);
        costHourDM.setCostLastHourDiff(costLastHourDiff);
        costHourDM.setCostLastTwoHour(costLastTwoHour);
        costHourDM.setCostLastTwoHourDiff(costLastTwoHourDiff);
        costHourDM.setCostLastThreeTrend(costLastThreeTrend);
        costHourDM.setCostLastThreeHour(costLastThreeHour);


        collector.collect(costHourDM);
        historyReduceState.remove(DateUtil.formatLocalDate(day.minusDays(2L)));
        historyReduceState.remove(DateUtil.formatLocalDate(day.minusDays(3L)));

    }

    //数据格式转换
    public CostHourDM dataChange(AdStatOfHourDWD hourDWD) {
        CostHourDM costHourDM = new CostHourDM();

        //时间-天
        costHourDM.setDt(hourDWD.getStatDay());
        //计划 id
        costHourDM.setCampaignId(hourDWD.getCampaignId().toString());
        //时间- real
        costHourDM.setCreateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(hourDWD.getCreateTime()));
        //时间-小时
        //TODO:之后需要进一步修改
        String tmpHour = hourDWD.getHour() > 9 ? hourDWD.getHour().toString() : "0" + hourDWD.getHour().toString();
        costHourDM.setHour(hourDWD.getStatDay() + " " + tmpHour + ":00:00");
        //广告id
        costHourDM.setAdId(hourDWD.getAdId().toString());
        //服务商id
        costHourDM.setAgencyAccountId(hourDWD.getAgencyAccountId().toString());
        //广告组id
        costHourDM.setAdgroupId(hourDWD.getAdgroupId().toString());
        //创意id
        costHourDM.setAdcreativeId("");
        //账号id
        costHourDM.setAccountId(hourDWD.getAccountId().toString());
        //总消耗
        costHourDM.setCostTotal(hourDWD.getCostTotal());
        //当天消耗
        costHourDM.setCostDay(hourDWD.getCostDay());
        //当天小时消耗
        costHourDM.setCostHour(hourDWD.getCostHour());
        //消耗速度
        costHourDM.setCostSpeed(hourDWD.getCostHour());
        //总浏览量
        costHourDM.setViewCountTotal(hourDWD.getViewCountTotal());
        //天-总浏览量
        costHourDM.setViewCountDay(hourDWD.getViewCountDay());
        //小时-总浏览量
        costHourDM.setViewCountHour(hourDWD.getViewCountHour());
        //总平均千次曝光成本
        costHourDM.setThousandDisplayPriceAll(hourDWD.getThousandDisplayPriceAll());
        //天-总平均曝光成本
        costHourDM.setThousandDisplayPriceDay(hourDWD.getThousandDisplayPriceDay());
        //小时-总平均曝光成本
        costHourDM.setThousandDisplayPriceHour(hourDWD.getThousandDisplayPriceHour());
        //总点击量
        costHourDM.setValidClickCountTotal(hourDWD.getValidClickCountTotal());
        //天-总点击量
        costHourDM.setValidClickCountDay(hourDWD.getValidClickCountDay());
        //小时-总点击量
        costHourDM.setValidClickCountHour(hourDWD.getValidClickCountHour());
        //总平均点击率
        costHourDM.setCtrAll(hourDWD.getCtrAll().doubleValue());
        //天-总平均点击率
        costHourDM.setCtrDay(hourDWD.getCtrDay().doubleValue());
        //小时-总平均点击率
        costHourDM.setCtrHour(hourDWD.getCtrHour().doubleValue());
        //总点击均价
        costHourDM.setCpcAll(hourDWD.getCpcAll());
        //天-总点击均价
        costHourDM.setCpcDay(hourDWD.getCpcDay());
        //小时-总点击均价
        costHourDM.setCpcHour(hourDWD.getCpcHour());
        //总目标转化量
        costHourDM.setConversionsCountTotal(hourDWD.getConversionsCountTotal());
        //天-总目标转化量
        costHourDM.setConversionsCountDay(hourDWD.getConversionsCountDay());
        //小时-总目标转化量
        costHourDM.setConversionsCountHour(hourDWD.getConversionsCountHour());
        //总目标平均转化成本
        costHourDM.setConversionsCostTotal(hourDWD.getConversionsCostAll());
        //天-总目标平均转化成本
        costHourDM.setConversionsCostDay(hourDWD.getConversionsCostDay());
        //小时-总目标平均转化成本
        costHourDM.setConversionsCostHour(hourDWD.getConversionsCostHour());
        //总平均转化率
        costHourDM.setConversionsRateAll(hourDWD.getConversionsRateAll().doubleValue());
        //天-总平均转化率
        costHourDM.setConversionsRateDay(hourDWD.getConversionsRateDay().doubleValue());
        //小时-总平均转化率
        costHourDM.setConversionsRateHour(hourDWD.getConversionsRateHour().doubleValue());
        //总首日下单roi
        Double tmpFirstDayOrderRoiTotal = hourDWD.getCostTotal() == 0 ? 0.0 : (double) hourDWD.getFirstDayOrderAmountTotal() / hourDWD.getCostTotal();
        costHourDM.setFirstDayOrderRoiTotal(tmpFirstDayOrderRoiTotal);
        //天-总首日下单roi
        Double tmpFirstDayOrderRoiDay = hourDWD.getCostDay() == 0 ? 0.0 : (double) hourDWD.getFirstDayOrderAmountDay() / hourDWD.getCostDay();
        costHourDM.setFirstDayOrderRoiDay(tmpFirstDayOrderRoiDay);
        //小时-总首日下单roi
        Double tmpFirstDayOrderRoiHour = hourDWD.getCostHour() == 0 ? 0.0 : (double) hourDWD.getFirstDayOrderAmountHour() / hourDWD.getCostHour();
        costHourDM.setFirstDayOrderRoiHour(tmpFirstDayOrderRoiHour);
        //总首日下单金额
        costHourDM.setFirstDayOrderAmountTotal(hourDWD.getFirstDayOrderAmountTotal());
        //天-总首日下单金额
        costHourDM.setFirstDayOrderAmountDay(hourDWD.getFirstDayOrderAmountDay());
        //小时-总首日下单金额
        costHourDM.setFirstDayOrderAmountHour(hourDWD.getFirstDayOrderAmountHour());
        //总首日下单量
        costHourDM.setFirstDayOrderCountTotal(hourDWD.getFirstDayOrderCountTotal());
        //天-总首日下单量
        costHourDM.setFirstDayOrderCountDay(hourDWD.getFirstDayOrderCountDay());
        //小时-总首日下单量
        costHourDM.setFirstDayOrderCountHour(hourDWD.getFirstDayOrderCountHour());
        //总下单金额
        costHourDM.setWebOrderAmountTotal(hourDWD.getOrderAmountTotal());
        //天-总下单金额
        costHourDM.setWebOrderAmountDay(hourDWD.getOrderAmountDay());
        //小时-总下单金额
        costHourDM.setWebOrderAmountHour(hourDWD.getOrderAmountHour());
        //总平均下单成本
        costHourDM.setWebOrderCostTotal(hourDWD.getWebOrderCostAll());
        //天-总平均下单成本
        costHourDM.setWebOrderCostDay(hourDWD.getWebOrderCostDay());
        //小时-总平均下单成本
        costHourDM.setWebOrderCostHour(hourDWD.getWebOrderCostHour());
        //总平均下单率
        costHourDM.setWebOrderRateTotal(hourDWD.getOrderRateAll().doubleValue());
        //天-总平均下单率
        costHourDM.setWebOrderRateDay(hourDWD.getOrderRateDay().doubleValue());
        //小时-总平均下单率
        costHourDM.setWebOrderRateHour(hourDWD.getOrderRateHour().doubleValue());
        //TODO:总平均下单量-----webordercount和ordercount是同一个东西吗
        costHourDM.setWebOrderCountTotal(hourDWD.getOrderCountTotal());
        //天-总平均下单量
        costHourDM.setWebOrderCountDay(hourDWD.getOrderCountDay());
        //小时-总平均下单量
        costHourDM.setWebOrderCountHour(hourDWD.getOrderCountHour());
        //总下单ROI
        costHourDM.setOrderRoiTotal(hourDWD.getOrderRoiAll().doubleValue());
        //天-总下单roi
        costHourDM.setOrderRoiDay(hourDWD.getOrderRoiDay().doubleValue());
        //小时-总下单roi
        costHourDM.setOrderRoiHour(hourDWD.getOrderRoiHour().doubleValue());
        //总平均下单客单价
        costHourDM.setOrderUnitPriceTotal(hourDWD.getOrderUnitPriceAll());
        //天-总平均下单客单价
        costHourDM.setOrderUnitPriceDay(hourDWD.getOrderUnitPriceDay());
        //小时-总平均下单客单价
        costHourDM.setOrderUnitPriceHour(hourDWD.getOrderUnitPriceHour());
        //总公众号关注量
        costHourDM.setFromFollowUvTotal(hourDWD.getOfficialAccountFollowCountTotal());
        //天-总公众号关注量
        costHourDM.setFromFollowUvDay(hourDWD.getOfficialAccountFollowCountDay());
        //小时-总公众号关注量
        costHourDM.setFromFollowUvHour(hourDWD.getOfficialAccountFollowCountHour());
        //TODO:总平均公众号关注成本---是否是价格/关注
        costHourDM.setFromFollowCostTotal(hourDWD.getOfficialAccountFollowCountTotal() == 0 ? 0 : hourDWD.getCostTotal() / hourDWD.getOfficialAccountFollowCountTotal());
        //天-总平均公众号关注成本
        costHourDM.setFromFollowCostDay(hourDWD.getOfficialAccountFollowCountDay() == 0 ? 0 : hourDWD.getCostDay() / hourDWD.getOfficialAccountFollowCountDay());
        //小时-总平均公众号关注成本
        costHourDM.setFromFollowCostHour(hourDWD.getOfficialAccountFollowCountHour() == 0 ? 0 : hourDWD.getCostHour() / hourDWD.getOfficialAccountFollowCountHour());
        //TODO:总平均公众号关注率----确认是否对应
        costHourDM.setFromFollowRateTotal(hourDWD.getOfficialAccountFollowRateAll().doubleValue());
        //天-总平均公众号关注率
        costHourDM.setFromFollowRateDay(hourDWD.getOfficialAccountFollowRateDay().doubleValue());
        //小时-总平均公众号关注率
        costHourDM.setFromFollowRateHour(hourDWD.getOfficialAccountFollowRateHour().doubleValue());
        //TODO:总注册数-----下面全是有问题的
        costHourDM.setWebRegisterCountTotal(hourDWD.getOfficialAccountRegisterUserCountTotal());
        //天-总注册数
        costHourDM.setWebRegisterCountDay(hourDWD.getOfficialAccountRegisterUserCountDay());
        //小时-总注册数
        costHourDM.setWebRegisterCountHour(hourDWD.getOfficialAccountRegisterUserCountHour());
        //总注册人数
        costHourDM.setWebRegisterUvTotal(hourDWD.getOfficialAccountRegisterUserCountTotal());
        //天-总注册人数
        costHourDM.setWebRegisterUvDay(hourDWD.getOfficialAccountRegisterUserCountDay());
        //小时-总注册人数
        costHourDM.setWebRegisterUvHour(hourDWD.getOfficialAccountRegisterUserCountHour());
        //总平均注册成本
        costHourDM.setWebRegisterCostTotal(hourDWD.getOfficialAccountRegisterCostAll());
        //天-总平均注册成本
        costHourDM.setWebRegisterCostDay(hourDWD.getOfficialAccountRegisterCostDay());
        //小时-总平均注册成本
        costHourDM.setWebRegisterCostHour(hourDWD.getOfficialAccountRegisterCostHour());
        return costHourDM;
    }
}
