package flink.zanxiangnet.ad.monitoring.process;

import flink.zanxiangnet.ad.monitoring.pojo.entity.*;
import flink.zanxiangnet.ad.monitoring.util.DateUtil;
import org.apache.flink.api.common.state.MapState;
import org.apache.flink.api.common.state.MapStateDescriptor;
import org.apache.flink.api.common.typeinfo.Types;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.streaming.api.functions.KeyedProcessFunction;
import org.apache.flink.util.Collector;

import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.util.*;

public class CostMinuteProcess extends KeyedProcessFunction<Long, AdStatOfMinuteDWD, CostMinuterDM> {
    private int minutenow = 1;
    // 之前聚合的昨天的数据
    private MapState<String, Map<Integer, AdStatOfMinuteDWD>> historyReduceState;

    @Override
    public void open(Configuration conf) throws Exception {
        historyReduceState = getRuntimeContext().getMapState(new MapStateDescriptor<>("historyReduceState", Types.STRING, Types.MAP(Types.INT, Types.POJO(AdStatOfMinuteDWD.class))));
    }

    @Override
    public void processElement(AdStatOfMinuteDWD adStatOfMinuteDWD, KeyedProcessFunction<Long, AdStatOfMinuteDWD, CostMinuterDM>.Context context,
                               Collector<CostMinuterDM> collector) throws Exception {
        LocalDate day = DateUtil.parseLocalDate(adStatOfMinuteDWD.getStatDay());
        Integer hour = adStatOfMinuteDWD.getHour();

        LocalDate lastHourDay = day, lastTwoHourDay = day, lastThreeHourDay = day;
        int lastHour = hour - 1, lastTwoHour = hour - 2, lastThreeHour = hour - 3;
        if (hour == 0) {
            lastHourDay = day.minusDays(1L);
            lastHour = 23;
            lastTwoHourDay = day.minusDays(1L);
            lastTwoHour = 22;
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 21;
        } else if (hour == 1) {
            lastTwoHourDay = day.minusDays(1L);
            lastTwoHour = 23;
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 22;
        } else if (hour == 2) {
            lastThreeHourDay = day.minusDays(1L);
            lastThreeHour = 23;
        }
        long costDiff = 0L, costLastHour = 0L;
        Map<Integer, AdStatOfMinuteDWD> lastHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastHourDay));
        if (lastHourMapping != null && !lastHourMapping.isEmpty()) {
            AdStatOfMinuteDWD lastHourDWD = lastHourMapping.get(lastHour);
            if (lastHourDWD != null) {
                costLastHour = lastHourDWD.getCostHour();
                costDiff = adStatOfMinuteDWD.getCostHour() - lastHourDWD.getCostHour();
            }
        }
        long costLastHourDiff = 0, costLastTwoHour = 0;
        Map<Integer, AdStatOfMinuteDWD> lastTwoHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastTwoHourDay));
        if (lastTwoHourMapping != null && !lastTwoHourMapping.isEmpty()) {
            AdStatOfMinuteDWD lastTwoHourDWD = lastTwoHourMapping.get(lastTwoHour);
            if (lastTwoHourDWD != null) {
                costLastTwoHour = lastTwoHourDWD.getCostHour();
                costLastHourDiff = costLastHour - lastTwoHourDWD.getCostHour();
            }
        }
        long costLastTwoHourDiff = 0, costLastThreeTrend = 0;
        Map<Integer, AdStatOfMinuteDWD> lastThreeHourMapping = historyReduceState.get(DateUtil.formatLocalDate(lastThreeHourDay));
        if (lastThreeHourMapping != null && !lastThreeHourMapping.isEmpty()) {
            AdStatOfMinuteDWD lastThreeHourDWD = lastThreeHourMapping.get(lastThreeHour);
            if (lastThreeHourDWD != null) {
                costLastThreeTrend = costLastHourDiff > 0 && costDiff > 0 ? 1 : 0;
                costLastTwoHourDiff = costLastTwoHour - lastThreeHourDWD.getCostHour();
            }
        }

        if (historyReduceState.get(adStatOfMinuteDWD.getStatDay()) == null) {
            Map<Integer, AdStatOfMinuteDWD> hourMapping = new HashMap<>(24);
            hourMapping.put(adStatOfMinuteDWD.getHour(), adStatOfMinuteDWD);
            historyReduceState.put(adStatOfMinuteDWD.getStatDay(), hourMapping);
        } else {
            historyReduceState.get(adStatOfMinuteDWD.getStatDay()).put(adStatOfMinuteDWD.getHour(), adStatOfMinuteDWD);
        }

        CostMinuterDM costMinuterDM = dataChange(adStatOfMinuteDWD);
        costMinuterDM.setCostDiff(costDiff);
        costMinuterDM.setCostLastHour(costLastHour);
        costMinuterDM.setCostLastHourDiff(costLastHourDiff);
        costMinuterDM.setCostLastTwoHour(costLastTwoHour);
        costMinuterDM.setCostLastTwoHourDiff(costLastTwoHourDiff);
        costMinuterDM.setCostLastThreeTrend(costLastThreeTrend);

        collector.collect(costMinuterDM);
        historyReduceState.remove(DateUtil.formatLocalDate(day.minusDays(2L)));
        historyReduceState.remove(DateUtil.formatLocalDate(day.minusDays(3L)));
    }

    //数据格式转换
    private CostMinuterDM dataChange(AdStatOfMinuteDWD adStatOfMinuteDWD) {
        CostMinuterDM costMinuterDM = new CostMinuterDM();
        //时间-天
        costMinuterDM.dt = adStatOfMinuteDWD.getStatDay();
        //计划 id
        costMinuterDM.campaignId = adStatOfMinuteDWD.getCampaignId().toString();
        //时间- real
        costMinuterDM.createTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(adStatOfMinuteDWD.getCreateTime());

        //时间-小时
        String tmpHour = new SimpleDateFormat("yyyy-MM-dd HH:00:00").format(new Date(adStatOfMinuteDWD.getStatTime()));
        costMinuterDM.hour = tmpHour;
        //时间-分钟
        String tmpMinute = new SimpleDateFormat("yyyy-MM-dd HH:mm:00").format(new Date(adStatOfMinuteDWD.getStatTime()));
        costMinuterDM.minute = tmpMinute;
        //广告id
        costMinuterDM.adId = adStatOfMinuteDWD.getAdId().toString();
        //服务商id
        costMinuterDM.agencyAccountId = adStatOfMinuteDWD.getAgencyAccountId().toString();
        //广告组id
        costMinuterDM.adgroupId = adStatOfMinuteDWD.getAdgroupId().toString();
        //创意id
        costMinuterDM.adcreativeId = "";
        //账号id
        costMinuterDM.accountId = adStatOfMinuteDWD.getAccountId().toString();
        //当天分钟消耗
        costMinuterDM.costMinute = adStatOfMinuteDWD.getCostMinute();
        //消耗速度-----分钟最小为1，部分分钟的速度会慢
        costMinuterDM.costSpeed = adStatOfMinuteDWD.getCostMinute() / this.minutenow;
        //分钟-总浏览量
        costMinuterDM.viewCountMinute = adStatOfMinuteDWD.getViewCountMinute();
        //分钟-总平均曝光成本
        costMinuterDM.thousandDisplayPriceMinute = adStatOfMinuteDWD.getThousandDisplayPriceMinute();
        //分钟-总点击量
        costMinuterDM.validClickCountMinute = adStatOfMinuteDWD.getValidClickCountMinute();
        //分钟-总平均点击率
        costMinuterDM.ctrMinute = adStatOfMinuteDWD.getCtrMinute().doubleValue();
        //分钟-总点击均价
        costMinuterDM.cpcMinute = adStatOfMinuteDWD.getCpcMinute();
        //分钟-总目标转化量
        costMinuterDM.conversionsCountMinute = adStatOfMinuteDWD.getConversionsCountMinute();
        //分钟-总目标平均转化成本
        costMinuterDM.conversionsCostMinute = adStatOfMinuteDWD.getConversionsCostMinute();
        //分钟-总平均转化率
        costMinuterDM.conversionsRateMinute = adStatOfMinuteDWD.getConversionsRateMinute().doubleValue();
        //TODO:分钟-总首日下单roi
        costMinuterDM.firstDayOrderRoiMinute = 0;
        //分钟-总首日下单金额
        costMinuterDM.firstDayOrderAmountMinute = adStatOfMinuteDWD.getFirstDayOrderAmountMinute();
        //分钟-总首日下单量
        costMinuterDM.firstDayOrderCountMinute = adStatOfMinuteDWD.getFirstDayOrderCountMinute();
        //分钟-总下单金额
        costMinuterDM.webOrderAmountMinute = adStatOfMinuteDWD.getOrderAmountMinute();
        //分钟-总平均下单成本
        costMinuterDM.webOrderCostMinute = adStatOfMinuteDWD.getWebOrderCostMinute();
        //分钟-总平均下单率
        costMinuterDM.webOrderRateMinute = adStatOfMinuteDWD.getOrderRateMinute().doubleValue();
        //TODO:分钟-总平均下单量
        costMinuterDM.webOrderCountMinute = adStatOfMinuteDWD.getOrderCountMinute();
        //分钟-总下单roi
        costMinuterDM.orderRoiMinute = adStatOfMinuteDWD.getOrderRoiMinute().doubleValue();
        //分钟-总平均下单客单价
        costMinuterDM.orderUnitPriceMinute = adStatOfMinuteDWD.getOrderUnitPriceMinute();
        //分钟-总公众号关注量
        costMinuterDM.fromFollowUvMinute = adStatOfMinuteDWD.getOfficialAccountFollowCountMinute();
        //TODO:分钟-总平均公众号关注成本
        costMinuterDM.fromFollowCostMinute = adStatOfMinuteDWD.getOfficialAccountFollowCountMinute() == 0 ? 0 : adStatOfMinuteDWD.getCostMinute() / adStatOfMinuteDWD.getOfficialAccountFollowCountMinute();
        //TODO:分钟-总平均公众号关注率
        costMinuterDM.fromFollowRateMinute = adStatOfMinuteDWD.getOfficialAccountFollowRateMinute().doubleValue();
        //TODO:分钟-总注册数-----下面都有问题
        costMinuterDM.webRegisterCountMinute = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountMinute();
        //分钟-总注册人数
        costMinuterDM.webRegisterUvMinute = adStatOfMinuteDWD.getOfficialAccountRegisterUserCountMinute();
        //分钟-总平均注册成本
        costMinuterDM.webRegisterCostMinute = adStatOfMinuteDWD.getOfficialAccountRegisterCostMinute();
        return costMinuterDM;
    }

}
